@@ -27,7 +27,12 @@ import (
 )
 
 const (
-	fileParamName = "file"
+	fileParamName  = "file"
+	cliMdDocHeader = "" +
+		"---\n" +
+		"title: CLI\n" +
+		"---\n\n" +
+		"# CLI\n\n"
 )
 
 type DumpDocsCmd struct {
@@ -88,6 +93,12 @@ func (cmd *DumpDocsCmd) Exec(ctx context.Context, commandStr string, args []stri
 		return 1
 	}
 
+	_, err = wr.Write([]byte(cliMdDocHeader))
+	if err != nil {
+		cli.PrintErrln(err.Error())
+		return 1
+	}
+
 	err = cmd.dumpDocs(wr, cmd.DoltCommand.Name(), cmd.DoltCommand.Subcommands)
 
 	if err != nil {
