@@ -22,7 +22,6 @@ import (
 	"strings"
 
 	sqle "github.com/dolthub/go-mysql-server"
-	"github.com/dolthub/go-mysql-server/auth"
 	"github.com/dolthub/go-mysql-server/sql"
 	"github.com/dolthub/go-mysql-server/sql/analyzer"
 	"github.com/dolthub/vitess/go/vt/sqlparser"
@@ -289,7 +288,7 @@ func rebaseSqlEngine(ctx context.Context, dEnv *env.DoltEnv, cm *doltdb.Commit)
 
 	sqlCtx.SetCurrentDatabase(dbName)
 
-	se := engine.NewRebasedSqlEngine(sqle.New(azr, &sqle.Config{Auth: new(auth.None)}), map[string]dsqle.SqlDatabase{dbName: db})
+	se := engine.NewRebasedSqlEngine(sqle.New(azr, &sqle.Config{IsReadOnly: false}), map[string]dsqle.SqlDatabase{dbName: db})
 
 	return sqlCtx, se, nil
 }
