@@ -79,17 +79,17 @@ By default this command uses the dolt data repository in the current working dir
 }
 
 const (
-	QueryFlag        = "query"
-	FormatFlag       = "result-format"
-	saveFlag         = "save"
-	executeFlag      = "execute"
-	listSavedFlag    = "list-saved"
-	messageFlag      = "message"
-	BatchFlag        = "batch"
-	disableBatchFlag = "disable-batch"
-	multiDBDirFlag   = "multi-db-dir"
-	continueFlag     = "continue"
-	welcomeMsg       = `# Welcome to the DoltSQL shell.
+	QueryFlag      = "query"
+	FormatFlag     = "result-format"
+	saveFlag       = "save"
+	executeFlag    = "execute"
+	listSavedFlag  = "list-saved"
+	messageFlag    = "message"
+	BatchFlag      = "batch"
+	multiDBDirFlag = "multi-db-dir"
+	continueFlag   = "continue"
+	fileInputFlag  = "file"
+	welcomeMsg     = `# Welcome to the DoltSQL shell.
 # Statements must be terminated with ';'.
 # "exit" or "quit" (or Ctrl-D) to exit.`
 )
@@ -104,7 +104,8 @@ type SqlCmd struct {
 	VersionStr string
 }
 
-// The SQL shell installs its own signal handlers so that you can cancel a running query without and still run a new one.
+// The SQL shell installs its own signal handlers so that you can cancel a running query without ending the entire
+// process
 func (cmd SqlCmd) InstallsSignalHandlers() bool {
 	return true
 }
@@ -135,10 +136,10 @@ func (cmd SqlCmd) ArgParser() *argparser.ArgParser {
 	ap.SupportsString(executeFlag, "x", "saved query name", "Executes a saved query with the given name")
 	ap.SupportsFlag(listSavedFlag, "l", "Lists all saved queries")
 	ap.SupportsString(messageFlag, "m", "saved query description", "Used with --query and --save, saves the query with the descriptive message given. See also --name")
-	ap.SupportsFlag(BatchFlag, "b", "batch mode, to run more than one query with --query, separated by ';'. Piping input to sql with no arguments also uses batch mode")
-	ap.SupportsFlag(disableBatchFlag, "", "When issuing multiple statements, used to override more efficient batch processing to give finer control over session")
+	ap.SupportsFlag(BatchFlag, "b", "Use to enable more efficient batch processing for large SQL import scripts consisting of only INSERT statements. Other statements types are not guaranteed to work in this mode.")
 	ap.SupportsString(multiDBDirFlag, "", "directory", "Defines a directory whose subdirectories should all be dolt data repositories accessible as independent databases within ")
 	ap.SupportsFlag(continueFlag, "c", "continue running queries on an error. Used for batch mode only.")
+	ap.SupportsString(fileInputFlag, "", "input file", "Execute statements from the file given")
 	return ap
 }
 
@@ -197,8 +198,6 @@ func (cmd SqlCmd) Exec(ctx context.Context, commandStr string, args []string, dE
 		}
 	}
 
-	_, continueOnError := apr.GetValue(continueFlag)
-
 	if query, queryOK := apr.GetValue(QueryFlag); queryOK {
 		return queryMode(ctx, mrEnv, initialRoots, apr, query, currentDb, format, usage)
 	} else if savedQueryName, exOk := apr.GetValue(executeFlag); exOk {
@@ -207,30 +206,41 @@ func (cmd SqlCmd) Exec(ctx context.Context, commandStr string, args []string, dE
 		return listSavedQueriesMode(ctx, mrEnv, initialRoots, currentDb, format, usage)
 	} else {
 		// Run in either batch mode for piped input, or shell mode for interactive
-		runInBatchMode := true
-		multiStatementMode := apr.Contains(disableBatchFlag)
-		fi, err := os.Stdin.Stat()
+		isTty := false
+		runInBatchMode := apr.Contains(BatchFlag)
 
+		fi, err := os.Stdin.Stat()
 		if err != nil {
 			if !osutil.IsWindows {
 				return HandleVErrAndExitCode(errhand.BuildDError("Couldn't stat STDIN. This is a bug.").Build(), usage)
 			}
 		} else {
-			runInBatchMode = fi.Mode()&os.ModeCharDevice == 0
+			isTty = fi.Mode()&os.ModeCharDevice != 0
 		}
 
-		if multiStatementMode {
-			verr := execMultiStatements(ctx, continueOnError, mrEnv, os.Stdin, format, currentDb)
+		_, continueOnError := apr.GetValue(continueFlag)
+
+		input := os.Stdin
+		if fileInput, ok := apr.GetValue(fileInputFlag); ok {
+			isTty = false
+			input, err = os.OpenFile(fileInput, os.O_RDONLY, os.ModePerm)
+			if err != nil {
+				return HandleVErrAndExitCode(errhand.BuildDError("couldn't open file %s", fileInput).Build(), usage)
+			}
+		}
+
+		if isTty {
+			verr := execShell(ctx, mrEnv, format, currentDb)
 			if verr != nil {
 				return HandleVErrAndExitCode(verr, usage)
 			}
 		} else if runInBatchMode {
-			verr := execBatch(ctx, continueOnError, mrEnv, os.Stdin, format, currentDb)
+			verr := execBatch(ctx, continueOnError, mrEnv, input, format, currentDb)
 			if verr != nil {
 				return HandleVErrAndExitCode(verr, usage)
 			}
 		} else {
-			verr := execShell(ctx, mrEnv, format, currentDb)
+			verr := execMultiStatements(ctx, continueOnError, mrEnv, input, format, currentDb)
 			if verr != nil {
 				return HandleVErrAndExitCode(verr, usage)
 			}
@@ -292,30 +302,22 @@ func queryMode(
 	format engine.PrintResultFormat,
 	usage cli.UsagePrinter,
 ) int {
+
+	// query mode has 3 sub modes:
+	// If --batch is provided, run with batch optimizations
+	// If --save is provided, run a single query and save it
+	// Otherwise, attempt to parse and execute multiple queries separated by ';'
 	batchMode := apr.Contains(BatchFlag)
-	multiStatementMode := apr.Contains(disableBatchFlag)
+	saveName := apr.GetValueOrDefault(saveFlag, "")
+
 	_, continueOnError := apr.GetValue(continueFlag)
 
-	if multiStatementMode {
-		batchInput := strings.NewReader(query)
-		verr := execMultiStatements(ctx, continueOnError, mrEnv, batchInput, format, currentDb)
-		if verr != nil {
-			return HandleVErrAndExitCode(verr, usage)
-		}
-	} else if batchMode {
-		batchInput := strings.NewReader(query)
-		verr := execBatch(ctx, continueOnError, mrEnv, batchInput, format, currentDb)
-		if verr != nil {
-			return HandleVErrAndExitCode(verr, usage)
-		}
-	} else {
+	if saveName != "" {
 		verr := execQuery(ctx, mrEnv, query, format, currentDb)
 		if verr != nil {
 			return HandleVErrAndExitCode(verr, usage)
 		}
 
-		saveName := apr.GetValueOrDefault(saveFlag, "")
-
 		if saveName != "" {
 			saveMessage := apr.GetValueOrDefault(messageFlag, "")
 			newRoot, verr := saveQuery(ctx, initialRoots[currentDb], query, saveName, saveMessage)
@@ -328,6 +330,18 @@ func queryMode(
 				return HandleVErrAndExitCode(verr, usage)
 			}
 		}
+	} else if batchMode {
+		batchInput := strings.NewReader(query)
+		verr := execBatch(ctx, continueOnError, mrEnv, batchInput, format, currentDb)
+		if verr != nil {
+			return HandleVErrAndExitCode(verr, usage)
+		}
+	} else {
+		input := strings.NewReader(query)
+		verr := execMultiStatements(ctx, continueOnError, mrEnv, input, format, currentDb)
+		if verr != nil {
+			return HandleVErrAndExitCode(verr, usage)
+		}
 	}
 
 	return 0
@@ -428,11 +442,6 @@ func execMultiStatements(
 	}
 
 	err = runMultiStatementMode(sqlCtx, se, batchInput, continueOnErr)
-	if err != nil {
-		// If we encounter an error, attempt to flush what we have so far to disk before exiting
-		return errhand.BuildDError("Error processing batch").AddCause(err).Build()
-	}
-
 	return errhand.VerboseErrorFromError(err)
 }
 
@@ -591,9 +600,6 @@ func validateSqlArgs(apr *argparser.ArgParseResults) error {
 	}
 
 	if batch {
-		if !query {
-			return errhand.BuildDError("Invalid Argument: --batch|-b must be used with --query|-q").Build()
-		}
 		if save || msg {
 			return errhand.BuildDError("Invalid Argument: --batch|-b is not compatible with --save|-s or --message|-m").Build()
 		}
@@ -625,7 +631,7 @@ func saveQuery(ctx context.Context, root *doltdb.RootValue, query string, name s
 	return newRoot, nil
 }
 
-// runMultiStatementMode alows for the execution of more than one query, but it doesn't attempt any batch optimizations
+// runMultiStatementMode allows for the execution of more than one query, but it doesn't attempt any batch optimizations
 func runMultiStatementMode(ctx *sql.Context, se *engine.SqlEngine, input io.Reader, continueOnErr bool) error {
 	scanner := NewSqlStatementScanner(input)
 
@@ -670,7 +676,6 @@ func runMultiStatementMode(ctx *sql.Context, se *engine.SqlEngine, input io.Read
 		query = ""
 	}
 
-	cli.Println() // need a newline after all statements are executed
 	if err := scanner.Err(); err != nil {
 		cli.Println(err.Error())
 	}
@@ -991,7 +996,7 @@ func processQuery(ctx *sql.Context, query string, se *engine.SqlEngine) (sql.Sch
 		if err != nil {
 			return nil, nil, err
 		}
-		_, err = sql.RowIterToRows(ctx, ri)
+		_, err = sql.RowIterToRows(ctx, nil, ri)
 		if err != nil {
 			return nil, nil, err
 		}
@@ -1002,7 +1007,7 @@ func processQuery(ctx *sql.Context, query string, se *engine.SqlEngine) (sql.Sch
 		if err != nil {
 			return nil, nil, err
 		}
-		_, err = sql.RowIterToRows(ctx, ri)
+		_, err = sql.RowIterToRows(ctx, nil, ri)
 		if err != nil {
 			return nil, nil, err
 		}
@@ -1012,7 +1017,7 @@ func processQuery(ctx *sql.Context, query string, se *engine.SqlEngine) (sql.Sch
 		if err != nil {
 			return nil, nil, err
 		}
-		_, err = sql.RowIterToRows(ctx, ri)
+		_, err = sql.RowIterToRows(ctx, nil, ri)
 		if err != nil {
 			return nil, nil, err
 		}
