@@ -91,16 +91,15 @@ In create, update, and replace scenarios the file's extension is used to infer t
 }
 
 type importOptions struct {
-	operation   mvdata.TableImportOp
-	tableName   string
-	contOnErr   bool
-	force       bool
-	schFile     string
-	primaryKeys []string
-	nameMapper  rowconv.NameMapper
-	src         mvdata.DataLocation
-	dest        mvdata.TableDataLocation
-	srcOptions  interface{}
+	operation     mvdata.TableImportOp
+	destTableName string
+	contOnErr     bool
+	force         bool
+	schFile       string
+	primaryKeys   []string
+	nameMapper    rowconv.NameMapper
+	src           mvdata.DataLocation
+	srcOptions    interface{}
 }
 
 func (m importOptions) WritesToTable() bool {
@@ -108,9 +107,6 @@ func (m importOptions) WritesToTable() bool {
 }
 
 func (m importOptions) SrcName() string {
-	if t, tblSrc := m.src.(mvdata.TableDataLocation); tblSrc {
-		return t.Name
-	}
 	if f, fileSrc := m.src.(mvdata.FileDataLocation); fileSrc {
 		return f.Path
 	}
@@ -118,7 +114,7 @@ func (m importOptions) SrcName() string {
 }
 
 func (m importOptions) DestName() string {
-	return m.dest.Name
+	return m.destTableName
 }
 
 func (m importOptions) ColNameMapper() rowconv.NameMapper {
@@ -131,7 +127,7 @@ func (m importOptions) FloatThreshold() float64 {
 
 func (m importOptions) checkOverwrite(ctx context.Context, root *doltdb.RootValue, fs filesys.ReadableFS) (bool, error) {
 	if !m.force && m.operation == mvdata.CreateOp {
-		return m.dest.Exists(ctx, root, fs)
+		return root.HasTable(ctx, m.destTableName)
 	}
 	return false, nil
 }
@@ -228,19 +224,16 @@ func getImportMoveOptions(ctx context.Context, apr *argparser.ArgParseResults, d
 		}
 	}
 
-	tableLoc := mvdata.TableDataLocation{Name: tableName}
-
 	return &importOptions{
-		operation:   moveOp,
-		tableName:   tableName,
-		contOnErr:   contOnErr,
-		force:       force,
-		schFile:     schemaFile,
-		nameMapper:  colMapper,
-		primaryKeys: pks,
-		src:         srcLoc,
-		dest:        tableLoc,
-		srcOptions:  srcOpts,
+		operation:     moveOp,
+		destTableName: tableName,
+		contOnErr:     contOnErr,
+		force:         force,
+		schFile:       schemaFile,
+		nameMapper:    colMapper,
+		primaryKeys:   pks,
+		src:           srcLoc,
+		srcOptions:    srcOpts,
 	}, nil
 
 }
@@ -285,11 +278,6 @@ func validateImportArgs(apr *argparser.ArgParseResults) errhand.VerboseError {
 		if !hasDelim && val.Format == mvdata.InvalidDataFormat {
 			return errhand.BuildDError("Could not infer type file '%s'\nFile extensions should match supported file types, or should be explicitly defined via the file-type parameter", path).Build()
 		}
-
-	case mvdata.TableDataLocation:
-		if hasDelim {
-			return errhand.BuildDError("delim is not a valid parameter for this type of file").Build()
-		}
 	}
 
 	if srcFileLoc, isFileType := srcLoc.(mvdata.FileDataLocation); isFileType {
@@ -387,13 +375,7 @@ func (cmd ImportCmd) Exec(ctx context.Context, commandStr string, args []string,
 		return commands.HandleVErrAndExitCode(verr, usage)
 	}
 
-	wrSch, nDMErr := getWriterSchema(ctx, root, dEnv, rd.GetSchema(), mvOpts)
-	if nDMErr != nil {
-		verr = newDataMoverErrToVerr(mvOpts, nDMErr)
-		return commands.HandleVErrAndExitCode(verr, usage)
-	}
-
-	wr, nDMErr := newImportDataWriter(ctx, dEnv, wrSch, mvOpts)
+	wr, nDMErr := newImportSqlEngineMover(ctx, dEnv, rd.GetSchema(), mvOpts)
 	if nDMErr != nil {
 		verr = newDataMoverErrToVerr(mvOpts, nDMErr)
 		return commands.HandleVErrAndExitCode(verr, usage)
@@ -440,7 +422,7 @@ func importStatsCB(stats types.AppliedEditStats) {
 	displayStrLen = cli.DeleteAndPrint(displayStrLen, displayStr)
 }
 
-func newImportDataReader(ctx context.Context, root *doltdb.RootValue, dEnv *env.DoltEnv, impOpts *importOptions) (table.TableReadCloser, *mvdata.DataMoverCreationError) {
+func newImportDataReader(ctx context.Context, root *doltdb.RootValue, dEnv *env.DoltEnv, impOpts *importOptions) (table.SqlRowReader, *mvdata.DataMoverCreationError) {
 	var err error
 
 	// Checks whether import destination table already exists. This can probably be simplified to not need a root value...
@@ -460,13 +442,17 @@ func newImportDataReader(ctx context.Context, root *doltdb.RootValue, dEnv *env.
 	return rd, nil
 }
 
-func getWriterSchema(ctx context.Context, root *doltdb.RootValue, dEnv *env.DoltEnv, rdSchema schema.Schema, imOpts *importOptions) (schema.Schema, *mvdata.DataMoverCreationError) {
-	wrSch, dmce := getImportSchema(ctx, root, dEnv.FS, imOpts)
+func newImportSqlEngineMover(ctx context.Context, dEnv *env.DoltEnv, rdSchema schema.Schema, imOpts *importOptions) (*mvdata.SqlEngineTableWriter, *mvdata.DataMoverCreationError) {
+	moveOps := &mvdata.MoverOptions{Force: imOpts.force, TableToWriteTo: imOpts.destTableName, ContinueOnErr: imOpts.contOnErr, Operation: imOpts.operation}
+
+	// Returns the schema of the table to be created or the existing schema
+	tableSchema, dmce := getImportSchema(ctx, dEnv, imOpts)
 	if dmce != nil {
 		return nil, dmce
 	}
 
-	err := wrSch.GetPKCols().Iter(func(tag uint64, col schema.Column) (stop bool, err error) {
+	// Validate that the schema from files has primary keys.
+	err := tableSchema.GetPKCols().Iter(func(tag uint64, col schema.Column) (stop bool, err error) {
 		preImage := imOpts.nameMapper.PreImage(col.Name)
 		_, found := rdSchema.GetAllCols().GetByName(preImage)
 		if !found {
@@ -478,36 +464,24 @@ func getWriterSchema(ctx context.Context, root *doltdb.RootValue, dEnv *env.Dolt
 		return nil, &mvdata.DataMoverCreationError{ErrType: mvdata.SchemaErr, Cause: err}
 	}
 
-	// allow subsetting of the final write schema only if it is an update operation. Every other operation must
-	// match perfectly.
-	if wrSch.GetAllCols().Size() != rdSchema.GetAllCols().Size() && imOpts.operation == mvdata.UpdateOp {
-		ret := schema.NewColCollection()
-
-		rdSchema.GetAllCols().Iter(func(tag uint64, col schema.Column) (stop bool, err error) {
-			wrColName := imOpts.nameMapper.Map(col.Name)
-			wrCol, ok := wrSch.GetAllCols().GetByName(wrColName)
-			if ok {
-				ret = ret.Append(wrCol)
-			}
-
-			return false, nil
-		})
-
-		newSch, err := schema.SchemaFromCols(ret)
-		if err != nil {
-			return nil, &mvdata.DataMoverCreationError{ErrType: mvdata.SchemaErr, Cause: err}
+	// construct the schema of the set of column to be updated.
+	rowOperationColColl := schema.NewColCollection()
+	rdSchema.GetAllCols().Iter(func(tag uint64, col schema.Column) (stop bool, err error) {
+		wrColName := imOpts.nameMapper.Map(col.Name)
+		wrCol, ok := tableSchema.GetAllCols().GetByName(wrColName)
+		if ok {
+			rowOperationColColl = rowOperationColColl.Append(wrCol)
 		}
 
-		return newSch, nil
+		return false, nil
+	})
+
+	rowOperationSchema, err := schema.SchemaFromCols(rowOperationColColl)
+	if err != nil {
+		return nil, &mvdata.DataMoverCreationError{ErrType: mvdata.SchemaErr, Cause: err}
 	}
 
-	return wrSch, nil
-}
-
-func newImportDataWriter(ctx context.Context, dEnv *env.DoltEnv, wrSchema schema.Schema, imOpts *importOptions) (mvdata.DataWriter, *mvdata.DataMoverCreationError) {
-	moveOps := &mvdata.MoverOptions{Force: imOpts.force, TableToWriteTo: imOpts.tableName, ContinueOnErr: imOpts.contOnErr, Operation: imOpts.operation}
-
-	mv, err := mvdata.NewSqlEngineMover(ctx, dEnv, wrSchema, moveOps, importStatsCB)
+	mv, err := mvdata.NewSqlEngineTableWriter(ctx, dEnv, tableSchema, rowOperationSchema, moveOps, importStatsCB)
 	if err != nil {
 		return nil, &mvdata.DataMoverCreationError{ErrType: mvdata.CreateWriterErr, Cause: err}
 	}
@@ -517,7 +491,7 @@ func newImportDataWriter(ctx context.Context, dEnv *env.DoltEnv, wrSchema schema
 
 type badRowFn func(trf *pipeline.TransformRowFailure) (quit bool)
 
-func move(ctx context.Context, rd table.TableReadCloser, wr mvdata.DataWriter, options *importOptions) (int64, error) {
+func move(ctx context.Context, rd table.SqlRowReader, wr *mvdata.SqlEngineTableWriter, options *importOptions) (int64, error) {
 	g, ctx := errgroup.WithContext(ctx)
 
 	// Setup the necessary data points for the import job
@@ -581,32 +555,19 @@ func move(ctx context.Context, rd table.TableReadCloser, wr mvdata.DataWriter, o
 
 func moveRows(
 	ctx context.Context,
-	wr mvdata.DataWriter,
-	rd table.TableReadCloser,
+	wr *mvdata.SqlEngineTableWriter,
+	rd table.SqlRowReader,
 	options *importOptions,
 	parsedRowChan chan sql.Row,
 	badRowCb badRowFn,
 ) error {
-	getNextRow := func(rd table.TableReadCloser) (sql.Row, error) {
-		if srd, ok := rd.(table.SqlRowReader); ok {
-			return srd.ReadSqlRow(ctx)
-		} else {
-			r, err := rd.ReadRow(ctx)
-			if err != nil {
-				return nil, err
-			}
-
-			return sqlutil.DoltRowToSqlRow(r, rd.GetSchema())
-		}
-	}
-
-	rdSqlSch, err := sqlutil.FromDoltSchema(options.tableName, rd.GetSchema())
+	rdSqlSch, err := sqlutil.FromDoltSchema(options.destTableName, rd.GetSchema())
 	if err != nil {
 		return err
 	}
 
 	for {
-		sqlRow, err := getNextRow(rd)
+		sqlRow, err := rd.ReadSqlRow(ctx)
 		if err == io.EOF {
 			return nil
 		}
@@ -622,7 +583,7 @@ func moveRows(
 				return err
 			}
 		} else {
-			sqlRow, err = NameAndTypeTransform(sqlRow, rdSqlSch.Schema, wr.Schema(), options.nameMapper)
+			sqlRow, err = NameAndTypeTransform(sqlRow, wr.RowOperationSchema(), rdSqlSch, options.nameMapper)
 			if err != nil {
 				return err
 			}
@@ -636,12 +597,17 @@ func moveRows(
 	}
 }
 
-func getImportSchema(ctx context.Context, root *doltdb.RootValue, fs filesys.Filesys, impOpts *importOptions) (schema.Schema, *mvdata.DataMoverCreationError) {
-	if impOpts.schFile != "" {
-		tn, out, err := mvdata.SchAndTableNameFromFile(ctx, impOpts.schFile, fs, root)
+func getImportSchema(ctx context.Context, dEnv *env.DoltEnv, impOpts *importOptions) (schema.Schema, *mvdata.DataMoverCreationError) {
+	root, err := dEnv.WorkingRoot(ctx)
+	if err != nil {
+		return nil, &mvdata.DataMoverCreationError{ErrType: mvdata.SchemaErr, Cause: err}
+	}
 
-		if err == nil && tn != impOpts.tableName {
-			err = fmt.Errorf("table name '%s' from schema file %s does not match table arg '%s'", tn, impOpts.schFile, impOpts.tableName)
+	if impOpts.schFile != "" {
+		tn, out, err := mvdata.SchAndTableNameFromFile(ctx, impOpts.schFile, dEnv.FS, root)
+
+		if err == nil && tn != impOpts.destTableName {
+			err = fmt.Errorf("table name '%s' from schema file %s does not match table arg '%s'", tn, impOpts.schFile, impOpts.destTableName)
 		}
 
 		if err != nil {
@@ -657,7 +623,7 @@ func getImportSchema(ctx context.Context, root *doltdb.RootValue, fs filesys.Fil
 			return nil, nil
 		}
 
-		rd, _, err := impOpts.src.NewReader(ctx, root, fs, impOpts.srcOptions)
+		rd, _, err := impOpts.src.NewReader(ctx, root, dEnv.FS, impOpts.srcOptions)
 		if err != nil {
 			return nil, &mvdata.DataMoverCreationError{ErrType: mvdata.CreateReaderErr, Cause: err}
 		}
@@ -667,7 +633,7 @@ func getImportSchema(ctx context.Context, root *doltdb.RootValue, fs filesys.Fil
 			return rd.GetSchema(), nil
 		}
 
-		outSch, err := mvdata.InferSchema(ctx, root, rd, impOpts.tableName, impOpts.primaryKeys, impOpts)
+		outSch, err := mvdata.InferSchema(ctx, root, rd, impOpts.destTableName, impOpts.primaryKeys, impOpts)
 		if err != nil {
 			return nil, &mvdata.DataMoverCreationError{ErrType: mvdata.SchemaErr, Cause: err}
 		}
@@ -676,7 +642,7 @@ func getImportSchema(ctx context.Context, root *doltdb.RootValue, fs filesys.Fil
 	}
 
 	// UpdateOp || ReplaceOp
-	tblRd, _, err := impOpts.dest.NewReader(ctx, root, fs, nil)
+	tblRd, err := mvdata.NewSqlEngineReader(ctx, dEnv, impOpts.destTableName)
 	if err != nil {
 		return nil, &mvdata.DataMoverCreationError{ErrType: mvdata.CreateReaderErr, Cause: err}
 	}
@@ -689,19 +655,19 @@ func newDataMoverErrToVerr(mvOpts *importOptions, err *mvdata.DataMoverCreationE
 	switch err.ErrType {
 	case mvdata.CreateReaderErr:
 		bdr := errhand.BuildDError("Error creating reader for %s.", mvOpts.src.String())
-		bdr.AddDetails("When attempting to move data from %s to %s, could not open a reader.", mvOpts.src.String(), mvOpts.dest.String())
+		bdr.AddDetails("When attempting to move data from %s to %s, could not open a reader.", mvOpts.src.String(), mvOpts.destTableName)
 		return bdr.AddCause(err.Cause).Build()
 
 	case mvdata.SchemaErr:
 		bdr := errhand.BuildDError("Error determining the output schema.")
-		bdr.AddDetails("When attempting to move data from %s to %s, could not determine the output schema.", mvOpts.src.String(), mvOpts.dest.String())
+		bdr.AddDetails("When attempting to move data from %s to %s, could not determine the output schema.", mvOpts.src.String(), mvOpts.destTableName)
 		bdr.AddDetails(`Schema File: "%s"`, mvOpts.schFile)
 		bdr.AddDetails(`explicit pks: "%s"`, strings.Join(mvOpts.primaryKeys, ","))
 		return bdr.AddCause(err.Cause).Build()
 
 	case mvdata.MappingErr:
 		bdr := errhand.BuildDError("Error determining the mapping from input fields to output fields.")
-		bdr.AddDetails("When attempting to move data from %s to %s, determine the mapping from input fields t, output fields.", mvOpts.src.String(), mvOpts.dest.String())
+		bdr.AddDetails("When attempting to move data from %s to %s, determine the mapping from input fields t, output fields.", mvOpts.src.String(), mvOpts.destTableName)
 		bdr.AddDetails(`Mapping File: "%s"`, mvOpts.nameMapper)
 		return bdr.AddCause(err.Cause).Build()
 
@@ -712,28 +678,19 @@ func newDataMoverErrToVerr(mvOpts *importOptions, err *mvdata.DataMoverCreationE
 
 	case mvdata.CreateMapperErr:
 		bdr := errhand.BuildDError("Error creating input to output mapper.")
-		details := fmt.Sprintf("When attempting to move data from %s to %s, could not create a mapper.", mvOpts.src.String(), mvOpts.dest.String())
+		details := fmt.Sprintf("When attempting to move data from %s to %s, could not create a mapper.", mvOpts.src.String(), mvOpts.destTableName)
 		bdr.AddDetails(details)
 		bdr.AddCause(err.Cause)
 
 		return bdr.AddCause(err.Cause).Build()
 
 	case mvdata.CreateWriterErr:
-		if err.Cause == mvdata.ErrNoPK {
-			builder := errhand.BuildDError("Attempting to write to %s with a schema that does not contain a primary key.", mvOpts.dest.String())
-			builder.AddDetails("A primary key is required and can be specified by:\n" +
-				"\tusing -pk option to designate a field as the primary key by name.\n" +
-				"\tusing -schema to provide a schema descriptor file.")
-			return builder.Build()
-		} else {
-			bdr := errhand.BuildDError("Error creating writer for %s.\n", mvOpts.dest.String())
-			bdr.AddDetails("When attempting to move data from %s to %s, could not open a writer.", mvOpts.src.String(), mvOpts.dest.String())
-			return bdr.AddCause(err.Cause).Build()
-		}
-
+		bdr := errhand.BuildDError("Error creating writer for %s.\n", mvOpts.destTableName)
+		bdr.AddDetails("When attempting to move data from %s to %s, could not open a writer.", mvOpts.src.String(), mvOpts.destTableName)
+		return bdr.AddCause(err.Cause).Build()
 	case mvdata.CreateSorterErr:
 		bdr := errhand.BuildDError("Error creating sorting reader.")
-		bdr.AddDetails("When attempting to move data from %s to %s, could not open create sorting reader.", mvOpts.src.String(), mvOpts.dest.String())
+		bdr.AddDetails("When attempting to move data from %s to %s, could not open create sorting reader.", mvOpts.src.String(), mvOpts.destTableName)
 		return bdr.AddCause(err.Cause).Build()
 	}
 
@@ -742,8 +699,10 @@ func newDataMoverErrToVerr(mvOpts *importOptions, err *mvdata.DataMoverCreationE
 
 // NameAndTypeTransform does 1) match the read and write schema with subsetting and name matching. 2) Address any
 // type inconsistencies.
-func NameAndTypeTransform(row sql.Row, rdSchema, wrSchema sql.Schema, nameMapper rowconv.NameMapper) (sql.Row, error) {
-	for i, col := range wrSchema {
+func NameAndTypeTransform(row sql.Row, rowOperationSchema sql.PrimaryKeySchema, rdSchema sql.PrimaryKeySchema, nameMapper rowconv.NameMapper) (sql.Row, error) {
+	row = applyMapperToRow(row, rowOperationSchema, rdSchema, nameMapper)
+
+	for i, col := range rowOperationSchema.Schema {
 		switch col.Type {
 		case sql.Boolean, sql.Int8, sql.MustCreateBitType(1): // TODO: noms bool wraps MustCreateBitType
 			switch row[i].(type) {
@@ -769,7 +728,7 @@ func NameAndTypeTransform(row sql.Row, rdSchema, wrSchema sql.Schema, nameMapper
 		}
 	}
 
-	return matchReadSchemaToWriteSchema(row, rdSchema, wrSchema, nameMapper), nil
+	return row, nil
 }
 
 func stringToBoolean(s string) (result bool, canConvert bool) {
@@ -802,22 +761,12 @@ func emptyStringToNil(val interface{}) interface{} {
 	return val
 }
 
-// matchReadSchemaToWriteSchema takes the read schema and accounts for subsetting and mapper (-m) differences.
-func matchReadSchemaToWriteSchema(row sql.Row, rdSchema, wrSchema sql.Schema, nameMapper rowconv.NameMapper) sql.Row {
-	returnRow := sql.Row{}
+func applyMapperToRow(row sql.Row, rowOperationSchema, rdSchema sql.PrimaryKeySchema, nameMapper rowconv.NameMapper) sql.Row {
+	returnRow := make(sql.Row, len(rowOperationSchema.Schema))
 
-	for _, wCol := range wrSchema {
-		seen := false
-		for rIdx, rCol := range rdSchema {
-			if rCol.Name == nameMapper.PreImage(wCol.Name) {
-				returnRow = append(returnRow, row[rIdx])
-				seen = true
-			}
-		}
-
-		if !seen {
-			returnRow = append(returnRow, nil)
-		}
+	for i, col := range rowOperationSchema.Schema {
+		rdIdx := rdSchema.IndexOf(nameMapper.PreImage(col.Name), col.Source)
+		returnRow[i] = row[rdIdx]
 	}
 
 	return returnRow
