@@ -32,24 +32,25 @@ type GSFactory struct {
 }
 
 // CreateDB creates an GCS backed database
-func (fact GSFactory) CreateDB(ctx context.Context, nbf *types.NomsBinFormat, urlObj *url.URL, params map[string]interface{}) (datas.Database, error) {
+func (fact GSFactory) CreateDB(ctx context.Context, nbf *types.NomsBinFormat, urlObj *url.URL, params map[string]interface{}) (datas.Database, types.ValueReadWriter, error) {
 	var db datas.Database
 	gcs, err := storage.NewClient(ctx)
 
 	if err != nil {
-		return nil, err
+		return nil, nil, err
 	}
 
 	bs := blobstore.NewGCSBlobstore(gcs, urlObj.Host, urlObj.Path)
 	gcsStore, err := nbs.NewBSStore(ctx, nbf.VersionString(), bs, defaultMemTableSize)
 
 	if err != nil {
-		return nil, err
+		return nil, nil, err
 	}
 
-	db = datas.NewDatabase(gcsStore)
+	vrw := types.NewValueStore(gcsStore)
+	db = datas.NewTypesDatabase(vrw)
 
-	return db, err
+	return db, vrw, nil
 }
 
 // LocalBSFactory is a DBFactory implementation for creating a local filesystem blobstore backed databases for testing
@@ -57,22 +58,23 @@ type LocalBSFactory struct {
 }
 
 // CreateDB creates a local filesystem blobstore backed database
-func (fact LocalBSFactory) CreateDB(ctx context.Context, nbf *types.NomsBinFormat, urlObj *url.URL, params map[string]interface{}) (datas.Database, error) {
+func (fact LocalBSFactory) CreateDB(ctx context.Context, nbf *types.NomsBinFormat, urlObj *url.URL, params map[string]interface{}) (datas.Database, types.ValueReadWriter, error) {
 	var db datas.Database
 	absPath, err := filepath.Abs(filepath.Join(urlObj.Host, urlObj.Path))
 
 	if err != nil {
-		return nil, err
+		return nil, nil, err
 	}
 
 	bs := blobstore.NewLocalBlobstore(absPath)
 	bsStore, err := nbs.NewBSStore(ctx, nbf.VersionString(), bs, defaultMemTableSize)
 
 	if err != nil {
-		return nil, err
+		return nil, nil, err
 	}
 
-	db = datas.NewDatabase(bsStore)
+	vrw := types.NewValueStore(bsStore)
+	db = datas.NewTypesDatabase(vrw)
 
-	return db, err
+	return db, vrw, err
 }
