@@ -28,8 +28,8 @@ import (
 	"github.com/dolthub/dolt/go/libraries/utils/filesys"
 	"github.com/dolthub/dolt/go/store/chunks"
 	"github.com/dolthub/dolt/go/store/datas"
+	"github.com/dolthub/dolt/go/store/datas/pull"
 	"github.com/dolthub/dolt/go/store/hash"
-	"github.com/dolthub/dolt/go/store/spec"
 	"github.com/dolthub/dolt/go/store/types"
 	"github.com/dolthub/dolt/go/store/types/edits"
 )
@@ -59,14 +59,16 @@ var ErrCannotDeleteLastBranch = errors.New("cannot delete the last branch")
 // Additionally the noms codebase uses panics in a way that is non idiomatic and We've opted to recover and return
 // errors in many cases.
 type DoltDB struct {
-	db datas.Database
+	db  hooksDatabase
+	vrw types.ValueReadWriter
 }
 
 // DoltDBFromCS creates a DoltDB from a noms chunks.ChunkStore
 func DoltDBFromCS(cs chunks.ChunkStore) *DoltDB {
-	db := datas.NewDatabase(cs)
+	vrw := types.NewValueStore(cs)
+	db := datas.NewTypesDatabase(vrw)
 
-	return &DoltDB{db}
+	return &DoltDB{hooksDatabase{Database: db}, vrw}
 }
 
 // LoadDoltDB will acquire a reference to the underlying noms db.  If the Location is InMemDoltDB then a reference
@@ -94,23 +96,23 @@ func LoadDoltDBWithParams(ctx context.Context, nbf *types.NomsBinFormat, urlStr
 		urlStr = fmt.Sprintf("file://%s", filepath.ToSlash(absPath))
 	}
 
-	db, err := dbfactory.CreateDB(ctx, nbf, urlStr, params)
+	db, vrw, err := dbfactory.CreateDB(ctx, nbf, urlStr, params)
 
 	if err != nil {
 		return nil, err
 	}
 
-	return &DoltDB{db}, nil
+	return &DoltDB{hooksDatabase{Database: db}, vrw}, nil
 }
 
 // NomsRoot returns the hash of the noms dataset map
 func (ddb *DoltDB) NomsRoot(ctx context.Context) (hash.Hash, error) {
-	return ddb.db.NomsRoot(ctx)
+	return datas.ChunkStoreFromDatabase(ddb.db).Root(ctx)
 }
 
 // CommitRoot executes a chunkStore commit, atomically swapping the root hash of the database manifest
 func (ddb *DoltDB) CommitRoot(ctx context.Context, last, current hash.Hash) (bool, error) {
-	return ddb.db.CommitRoot(ctx, last, current)
+	return datas.ChunkStoreFromDatabase(ddb.db).Commit(ctx, last, current)
 }
 
 func (ddb *DoltDB) CSMetricsSummary() string {
@@ -151,7 +153,7 @@ func (ddb *DoltDB) WriteEmptyRepoWithCommitTimeAndDefaultBranch(
 		return errors.New("database already exists")
 	}
 
-	rv, err := EmptyRootValue(ctx, ddb.db)
+	rv, err := EmptyRootValue(ctx, ddb.vrw)
 
 	if err != nil {
 		return err
@@ -165,18 +167,18 @@ func (ddb *DoltDB) WriteEmptyRepoWithCommitTimeAndDefaultBranch(
 
 	cm, _ := NewCommitMetaWithUserTS(name, email, "Initialize data repository", t)
 
-	parents, err := types.NewList(ctx, ddb.db)
+	parents, err := types.NewList(ctx, ddb.vrw)
 	if err != nil {
 		return err
 	}
 
-	meta, err := cm.toNomsStruct(ddb.db.Format())
+	meta, err := cm.toNomsStruct(ddb.vrw.Format())
 
 	if err != nil {
 		return err
 	}
 
-	commitOpts := datas.CommitOptions{ParentsList: parents, Meta: meta, Policy: nil}
+	commitOpts := datas.CommitOptions{ParentsList: parents, Meta: meta}
 
 	cb := ref.NewInternalRef(creationBranch)
 	ds, err = ddb.db.GetDataset(ctx, cb.String())
@@ -212,21 +214,21 @@ func (ddb *DoltDB) WriteEmptyRepoWithCommitTimeAndDefaultBranch(
 	return err
 }
 
-func getCommitStForRefStr(ctx context.Context, db datas.Database, ref string) (types.Struct, error) {
+func getCommitStForRefStr(ctx context.Context, db datas.Database, vrw types.ValueReadWriter, ref string) (types.Struct, error) {
 	if !datas.DatasetFullRe.MatchString(ref) {
-		return types.EmptyStruct(db.Format()), fmt.Errorf("invalid ref format: %s", ref)
+		return types.Struct{}, fmt.Errorf("invalid ref format: %s", ref)
 	}
 
 	ds, err := db.GetDataset(ctx, ref)
 
 	if err != nil {
-		return types.EmptyStruct(db.Format()), err
+		return types.Struct{}, err
 	}
 
 	dsHead, hasHead := ds.MaybeHead()
 
 	if !hasHead {
-		return types.EmptyStruct(db.Format()), ErrBranchNotFound
+		return types.Struct{}, ErrBranchNotFound
 	}
 
 	if dsHead.Name() == datas.CommitName {
@@ -236,48 +238,43 @@ func getCommitStForRefStr(ctx context.Context, db datas.Database, ref string) (t
 	if dsHead.Name() == datas.TagName {
 		commitRef, ok, err := dsHead.MaybeGet(datas.TagCommitRefField)
 		if err != nil {
-			return types.EmptyStruct(db.Format()), err
+			return types.Struct{}, err
 		}
 		if !ok {
 			err = fmt.Errorf("tag struct does not have field %s", datas.TagCommitRefField)
-			return types.EmptyStruct(db.Format()), err
+			return types.Struct{}, err
 		}
 
-		commitSt, err := commitRef.(types.Ref).TargetValue(ctx, db)
+		commitSt, err := commitRef.(types.Ref).TargetValue(ctx, vrw)
 		if err != nil {
-			return types.EmptyStruct(db.Format()), err
+			return types.Struct{}, err
 		}
 
 		return commitSt.(types.Struct), nil
 	}
 
 	err = fmt.Errorf("dataset head is neither commit nor tag")
-	return types.EmptyStruct(db.Format()), err
+	return types.Struct{}, err
 }
 
-func getCommitStForHash(ctx context.Context, db datas.Database, c string) (types.Struct, error) {
-	prefixed := c
-
-	if !strings.HasPrefix(c, "#") {
-		prefixed = "#" + c
+func getCommitStForHash(ctx context.Context, vr types.ValueReader, c string) (types.Struct, error) {
+	unprefixed := strings.TrimPrefix(c, "#")
+	hash, ok := hash.MaybeParse(unprefixed)
+	if !ok {
+		return types.Struct{}, errors.New("invalid hash: " + c)
 	}
 
-	ap, err := spec.NewAbsolutePath(prefixed)
-
+	val, err := vr.ReadValue(ctx, hash)
 	if err != nil {
-		return types.EmptyStruct(db.Format()), err
+		return types.Struct{}, err
 	}
-
-	val := ap.Resolve(ctx, db)
-
 	if val == nil {
-		return types.EmptyStruct(db.Format()), ErrHashNotFound
+		return types.Struct{}, ErrHashNotFound
 	}
 
 	valSt, ok := val.(types.Struct)
-
 	if !ok || valSt.Name() != CommitStructName {
-		return types.EmptyStruct(db.Format()), ErrFoundHashNotACommit
+		return types.Struct{}, ErrFoundHashNotACommit
 	}
 
 	return valSt, nil
@@ -344,7 +341,7 @@ func (ddb *DoltDB) Resolve(ctx context.Context, cs *CommitSpec, cwb ref.DoltRef)
 	var err error
 	switch cs.csType {
 	case hashCommitSpec:
-		commitSt, err = getCommitStForHash(ctx, ddb.db, cs.baseSpec)
+		commitSt, err = getCommitStForHash(ctx, ddb.vrw, cs.baseSpec)
 	case refCommitSpec:
 		// For a ref in a CommitSpec, we have the following behavior.
 		// If it starts with `refs/`, we look for an exact match before
@@ -367,7 +364,7 @@ func (ddb *DoltDB) Resolve(ctx context.Context, cs *CommitSpec, cwb ref.DoltRef)
 			}
 		}
 		for _, candidate := range candidates {
-			commitSt, err = getCommitStForRefStr(ctx, ddb.db, candidate)
+			commitSt, err = getCommitStForRefStr(ctx, ddb.db, ddb.vrw, candidate)
 			if err == nil {
 				break
 			}
@@ -379,7 +376,7 @@ func (ddb *DoltDB) Resolve(ctx context.Context, cs *CommitSpec, cwb ref.DoltRef)
 		if cwb == nil {
 			return nil, fmt.Errorf("cannot use a nil current working branch with a HEAD commit spec")
 		}
-		commitSt, err = getCommitStForRefStr(ctx, ddb.db, cwb.String())
+		commitSt, err = getCommitStForRefStr(ctx, ddb.db, ddb.vrw, cwb.String())
 	default:
 		panic("unrecognized commit spec csType: " + cs.csType)
 	}
@@ -388,23 +385,23 @@ func (ddb *DoltDB) Resolve(ctx context.Context, cs *CommitSpec, cwb ref.DoltRef)
 		return nil, err
 	}
 
-	commitSt, err = getAncestor(ctx, ddb.db, commitSt, cs.aSpec)
+	commitSt, err = getAncestor(ctx, ddb.vrw, commitSt, cs.aSpec)
 
 	if err != nil {
 		return nil, err
 	}
 
-	return NewCommit(ddb.db, commitSt), nil
+	return NewCommit(ddb.vrw, commitSt), nil
 }
 
 // ResolveCommitRef takes a DoltRef and returns a Commit, or an error if the commit cannot be found. The ref given must
 // point to a Commit.
 func (ddb *DoltDB) ResolveCommitRef(ctx context.Context, ref ref.DoltRef) (*Commit, error) {
-	commitSt, err := getCommitStForRefStr(ctx, ddb.db, ref.String())
+	commitSt, err := getCommitStForRefStr(ctx, ddb.db, ddb.vrw, ref.String())
 	if err != nil {
 		return nil, err
 	}
-	return NewCommit(ddb.db, commitSt), nil
+	return NewCommit(ddb.vrw, commitSt), nil
 }
 
 // ResolveTag takes a TagRef and returns the corresponding Tag object.
@@ -425,7 +422,7 @@ func (ddb *DoltDB) ResolveTag(ctx context.Context, tagRef ref.TagRef) (*Tag, err
 		return nil, fmt.Errorf("tagRef head is not a tag")
 	}
 
-	return NewTag(ctx, tagRef.GetPath(), ddb.db, tagSt)
+	return NewTag(ctx, tagRef.GetPath(), ddb.vrw, tagSt)
 }
 
 // ResolveWorkingSet takes a WorkingSetRef and returns the corresponding WorkingSet object.
@@ -446,7 +443,7 @@ func (ddb *DoltDB) ResolveWorkingSet(ctx context.Context, workingSetRef ref.Work
 		return nil, fmt.Errorf("workingSetRef head is not a workingSetRef")
 	}
 
-	return NewWorkingSet(ctx, workingSetRef.GetPath(), ddb.db, wsSt)
+	return NewWorkingSet(ctx, workingSetRef.GetPath(), ddb.vrw, wsSt)
 }
 
 // TODO: convenience method to resolve the head commit of a branch.
@@ -460,12 +457,6 @@ func (ddb *DoltDB) WriteRootValue(ctx context.Context, rv *RootValue) (hash.Hash
 	if err != nil {
 		return hash.Hash{}, err
 	}
-
-	err = ddb.db.Flush(ctx)
-	if err != nil {
-		return hash.Hash{}, err
-	}
-
 	return valRef.TargetHash(), nil
 }
 
@@ -480,13 +471,13 @@ func (ddb *DoltDB) writeRootValue(ctx context.Context, rv *RootValue) (types.Ref
 		return types.Ref{}, err
 	}
 
-	return ddb.db.WriteValue(ctx, rv.valueSt)
+	return ddb.vrw.WriteValue(ctx, rv.valueSt)
 }
 
 // ReadRootValue reads the RootValue associated with the hash given and returns it. Returns an error if the value cannot
 // be read, or if the hash given doesn't represent a dolt RootValue.
 func (ddb *DoltDB) ReadRootValue(ctx context.Context, h hash.Hash) (*RootValue, error) {
-	val, err := ddb.db.ReadValue(ctx, h)
+	val, err := ddb.vrw.ReadValue(ctx, h)
 
 	if err != nil {
 		return nil, err
@@ -500,7 +491,7 @@ func (ddb *DoltDB) ReadRootValue(ctx context.Context, h hash.Hash) (*RootValue,
 		return nil, ErrNoRootValAtHash
 	}
 
-	return newRootValue(ddb.db, rootSt)
+	return newRootValue(ddb.vrw, rootSt)
 }
 
 // Commit will update a branch's head value to be that of a previously committed root value hash
@@ -520,7 +511,7 @@ func (ddb *DoltDB) FastForward(ctx context.Context, branch ref.DoltRef, commit *
 		return err
 	}
 
-	rf, err := types.NewRef(commit.commitSt, ddb.db.Format())
+	rf, err := types.NewRef(commit.commitSt, ddb.vrw.Format())
 
 	if err != nil {
 		return err
@@ -549,7 +540,7 @@ func (ddb *DoltDB) CanFastForward(ctx context.Context, branch ref.DoltRef, new *
 // SetHeadToCommit sets the given ref to point at the given commit. It is used in the course of 'force' updates.
 func (ddb *DoltDB) SetHeadToCommit(ctx context.Context, ref ref.DoltRef, cm *Commit) error {
 
-	stRef, err := types.NewRef(cm.commitSt, ddb.db.Format())
+	stRef, err := types.NewRef(cm.commitSt, ddb.vrw.Format())
 
 	if err != nil {
 		return err
@@ -585,7 +576,7 @@ func (ddb *DoltDB) CommitWithParentSpecs(ctx context.Context, valHash hash.Hash,
 }
 
 func (ddb *DoltDB) CommitWithParentCommits(ctx context.Context, valHash hash.Hash, dref ref.DoltRef, parentCommits []*Commit, cm *CommitMeta) (*Commit, error) {
-	val, err := ddb.db.ReadValue(ctx, valHash)
+	val, err := ddb.vrw.ReadValue(ctx, valHash)
 
 	if err != nil {
 		return nil, err
@@ -601,7 +592,7 @@ func (ddb *DoltDB) CommitWithParentCommits(ctx context.Context, valHash hash.Has
 		return nil, err
 	}
 
-	l, err := types.NewList(ctx, ddb.db)
+	l, err := types.NewList(ctx, ddb.vrw)
 
 	if err != nil {
 		return nil, err
@@ -620,7 +611,7 @@ func (ddb *DoltDB) CommitWithParentCommits(ctx context.Context, valHash hash.Has
 	}
 
 	for _, cm := range parentCommits {
-		rf, err := types.NewRef(cm.commitSt, ddb.db.Format())
+		rf, err := types.NewRef(cm.commitSt, ddb.vrw.Format())
 
 		if err != nil {
 			return nil, err
@@ -635,13 +626,13 @@ func (ddb *DoltDB) CommitWithParentCommits(ctx context.Context, valHash hash.Has
 		return nil, err
 	}
 
-	st, err := cm.toNomsStruct(ddb.db.Format())
+	st, err := cm.toNomsStruct(ddb.vrw.Format())
 
 	if err != nil {
 		return nil, err
 	}
 
-	commitOpts := datas.CommitOptions{ParentsList: parents, Meta: st, Policy: nil}
+	commitOpts := datas.CommitOptions{ParentsList: parents, Meta: st}
 	ds, err = ddb.db.GetDataset(ctx, dref.String())
 
 	if err != nil {
@@ -659,14 +650,14 @@ func (ddb *DoltDB) CommitWithParentCommits(ctx context.Context, valHash hash.Has
 		return nil, errors.New("Commit has no head but commit succeeded. This is a bug.")
 	}
 
-	return NewCommit(ddb.db, commitSt), nil
+	return NewCommit(ddb.vrw, commitSt), nil
 }
 
 // dangling commits are unreferenced by any branch or ref. They are created in the course of programmatic updates
 // such as rebase. You must create a ref to a dangling commit for it to be reachable
 func (ddb *DoltDB) CommitDanglingWithParentCommits(ctx context.Context, valHash hash.Hash, parentCommits []*Commit, cm *CommitMeta) (*Commit, error) {
 	var commitSt types.Struct
-	val, err := ddb.db.ReadValue(ctx, valHash)
+	val, err := ddb.vrw.ReadValue(ctx, valHash)
 	if err != nil {
 		return nil, err
 	}
@@ -674,7 +665,7 @@ func (ddb *DoltDB) CommitDanglingWithParentCommits(ctx context.Context, valHash
 		return nil, errors.New("can't commit a value that is not a valid root value")
 	}
 
-	l, err := types.NewList(ctx, ddb.db)
+	l, err := types.NewList(ctx, ddb.vrw)
 	if err != nil {
 		return nil, err
 	}
@@ -682,7 +673,7 @@ func (ddb *DoltDB) CommitDanglingWithParentCommits(ctx context.Context, valHash
 	parentEditor := l.Edit()
 
 	for _, cm := range parentCommits {
-		rf, err := types.NewRef(cm.commitSt, ddb.db.Format())
+		rf, err := types.NewRef(cm.commitSt, ddb.vrw.Format())
 		if err != nil {
 			return nil, err
 		}
@@ -695,27 +686,32 @@ func (ddb *DoltDB) CommitDanglingWithParentCommits(ctx context.Context, valHash
 		return nil, err
 	}
 
-	st, err := cm.toNomsStruct(ddb.db.Format())
+	st, err := cm.toNomsStruct(ddb.vrw.Format())
 	if err != nil {
 		return nil, err
 	}
 
-	commitOpts := datas.CommitOptions{ParentsList: parents, Meta: st, Policy: nil}
-	commitSt, err = ddb.db.CommitDangling(ctx, val, commitOpts)
+	commitOpts := datas.CommitOptions{ParentsList: parents, Meta: st}
+	commitSt, err = datas.NewCommitForValue(ctx, ddb.vrw, val, commitOpts)
 	if err != nil {
 		return nil, err
 	}
 
-	return NewCommit(ddb.db, commitSt), nil
+	_, err = ddb.vrw.WriteValue(ctx, commitSt)
+	if err != nil {
+		return nil, err
+	}
+
+	return NewCommit(ddb.vrw, commitSt), nil
 }
 
 // ValueReadWriter returns the underlying noms database as a types.ValueReadWriter.
 func (ddb *DoltDB) ValueReadWriter() types.ValueReadWriter {
-	return ddb.db
+	return ddb.vrw
 }
 
 func (ddb *DoltDB) Format() *types.NomsBinFormat {
-	return ddb.db.Format()
+	return ddb.vrw.Format()
 }
 
 func WriteValAndGetRef(ctx context.Context, vrw types.ValueReadWriter, val types.Value) (types.Ref, error) {
@@ -771,13 +767,14 @@ func (ddb *DoltDB) ResolveAllParents(ctx context.Context, commit *Commit) ([]*Co
 
 // HasRef returns whether the branch given exists in this database.
 func (ddb *DoltDB) HasRef(ctx context.Context, doltRef ref.DoltRef) (bool, error) {
-	dss, err := ddb.db.Datasets(ctx)
-
+	ds, err := ddb.db.GetDataset(ctx, doltRef.String())
 	if err != nil {
+		if errors.Is(err, datas.ErrInvalidDatasetID) {
+			return false, nil
+		}
 		return false, err
 	}
-
-	return dss.Has(ctx, types.String(doltRef.String()))
+	return ds.HasHead(), nil
 }
 
 var branchRefFilter = map[ref.RefType]struct{}{ref.BranchRefType: {}}
@@ -794,10 +791,8 @@ type BranchWithHash struct {
 
 func (ddb *DoltDB) GetBranchesWithHashes(ctx context.Context) ([]BranchWithHash, error) {
 	var refs []BranchWithHash
-	err := ddb.VisitRefsOfType(ctx, branchRefFilter, func(r ref.DoltRef, v types.Value) error {
-		if tr, ok := v.(types.Ref); ok {
-			refs = append(refs, BranchWithHash{r, tr.TargetHash()})
-		}
+	err := ddb.VisitRefsOfType(ctx, branchRefFilter, func(r ref.DoltRef, addr hash.Hash) error {
+		refs = append(refs, BranchWithHash{r, addr})
 		return nil
 	})
 	return refs, err
@@ -810,6 +805,31 @@ func (ddb *DoltDB) GetTags(ctx context.Context) ([]ref.DoltRef, error) {
 	return ddb.GetRefsOfType(ctx, tagsRefFilter)
 }
 
+type TagWithHash struct {
+	Ref  ref.DoltRef
+	Hash hash.Hash
+}
+
+// GetTagsWithHashes returns a list of objects containing TagRefs with their associated Commit's hash
+func (ddb *DoltDB) GetTagsWithHashes(ctx context.Context) ([]TagWithHash, error) {
+	var refs []TagWithHash
+	err := ddb.VisitRefsOfType(ctx, tagsRefFilter, func(r ref.DoltRef, _ hash.Hash) error {
+		if tr, ok := r.(ref.TagRef); ok {
+			tag, err := ddb.ResolveTag(ctx, tr)
+			if err != nil {
+				return err
+			}
+			h, err := tag.Commit.HashOf()
+			if err != nil {
+				return err
+			}
+			refs = append(refs, TagWithHash{r, h})
+		}
+		return nil
+	})
+	return refs, err
+}
+
 var workspacesRefFilter = map[ref.RefType]struct{}{ref.WorkspaceRefType: {}}
 
 // GetWorkspaces returns a list of all workspaces in the database.
@@ -824,19 +844,33 @@ func (ddb *DoltDB) GetRemoteRefs(ctx context.Context) ([]ref.DoltRef, error) {
 	return ddb.GetRefsOfType(ctx, remotesRefFilter)
 }
 
+type RemoteWithHash struct {
+	Ref  ref.DoltRef
+	Hash hash.Hash
+}
+
+func (ddb *DoltDB) GetRemotesWithHashes(ctx context.Context) ([]RemoteWithHash, error) {
+	var refs []RemoteWithHash
+	err := ddb.VisitRefsOfType(ctx, remotesRefFilter, func(r ref.DoltRef, addr hash.Hash) error {
+		refs = append(refs, RemoteWithHash{r, addr})
+		return nil
+	})
+	return refs, err
+}
+
 // GetHeadRefs returns a list of all refs that point to a Commit
 func (ddb *DoltDB) GetHeadRefs(ctx context.Context) ([]ref.DoltRef, error) {
 	return ddb.GetRefsOfType(ctx, ref.HeadRefTypes)
 }
 
-func (ddb *DoltDB) VisitRefsOfType(ctx context.Context, refTypeFilter map[ref.RefType]struct{}, visit func(r ref.DoltRef, v types.Value) error) error {
+func (ddb *DoltDB) VisitRefsOfType(ctx context.Context, refTypeFilter map[ref.RefType]struct{}, visit func(r ref.DoltRef, addr hash.Hash) error) error {
 	dss, err := ddb.db.Datasets(ctx)
 	if err != nil {
 		return err
 	}
 
-	return dss.IterAll(ctx, func(key, v types.Value) error {
-		keyStr := string(key.(types.String))
+	return dss.IterAll(ctx, func(key string, addr hash.Hash) error {
+		keyStr := key
 
 		var dref ref.DoltRef
 		if ref.IsRef(keyStr) {
@@ -846,7 +880,7 @@ func (ddb *DoltDB) VisitRefsOfType(ctx context.Context, refTypeFilter map[ref.Re
 			}
 
 			if _, ok := refTypeFilter[dref.GetType()]; ok {
-				err = visit(dref, v)
+				err = visit(dref, addr)
 				if err != nil {
 					return err
 				}
@@ -859,7 +893,7 @@ func (ddb *DoltDB) VisitRefsOfType(ctx context.Context, refTypeFilter map[ref.Re
 
 func (ddb *DoltDB) GetRefsOfType(ctx context.Context, refTypeFilter map[ref.RefType]struct{}) ([]ref.DoltRef, error) {
 	var refs []ref.DoltRef
-	err := ddb.VisitRefsOfType(ctx, refTypeFilter, func(r ref.DoltRef, v types.Value) error {
+	err := ddb.VisitRefsOfType(ctx, refTypeFilter, func(r ref.DoltRef, _ hash.Hash) error {
 		refs = append(refs, r)
 		return nil
 	})
@@ -877,7 +911,7 @@ func (ddb *DoltDB) NewBranchAtCommit(ctx context.Context, branchRef ref.DoltRef,
 		return err
 	}
 
-	rf, err := types.NewRef(commit.commitSt, ddb.db.Format())
+	rf, err := types.NewRef(commit.commitSt, ddb.vrw.Format())
 	if err != nil {
 		return err
 	}
@@ -1003,7 +1037,7 @@ func (ddb *DoltDB) NewTagAtCommit(ctx context.Context, tagRef ref.DoltRef, c *Co
 		return err
 	}
 
-	st, err := meta.toNomsStruct(ddb.db.Format())
+	st, err := meta.toNomsStruct(ddb.vrw.Format())
 
 	if err != nil {
 		return err
@@ -1079,7 +1113,7 @@ func (ddb *DoltDB) CommitWithWorkingSet(
 	}
 
 	var metaSt types.Struct
-	metaSt, err = meta.toNomsStruct(ddb.db.Format())
+	metaSt, err = meta.toNomsStruct(ddb.vrw.Format())
 	if err != nil {
 		return nil, err
 	}
@@ -1100,7 +1134,7 @@ func (ddb *DoltDB) CommitWithWorkingSet(
 		return nil, errors.New("Commit has no head but commit succeeded. This is a bug.")
 	}
 
-	return NewCommit(ddb.db, commitSt), nil
+	return NewCommit(ddb.vrw, commitSt), nil
 }
 
 // DeleteWorkingSet deletes the working set given
@@ -1154,12 +1188,12 @@ func (ddb *DoltDB) DeleteWorkspace(ctx context.Context, workRef ref.DoltRef) err
 // Rebase rebases the underlying db from disk, re-loading the manifest. Useful when another process might have made
 // changes to the database we need to read.
 func (ddb *DoltDB) Rebase(ctx context.Context) error {
-	return ddb.db.Rebase(ctx)
+	return datas.ChunkStoreFromDatabase(ddb.db).Rebase(ctx)
 }
 
 // GC performs garbage collection on this ddb. Values passed in |uncommitedVals| will be temporarily saved during gc.
 func (ddb *DoltDB) GC(ctx context.Context, uncommitedVals ...hash.Hash) error {
-	collector, ok := ddb.db.(datas.GarbageCollector)
+	collector, ok := ddb.db.Database.(datas.GarbageCollector)
 	if !ok {
 		return fmt.Errorf("this database does not support garbage collection")
 	}
@@ -1170,12 +1204,12 @@ func (ddb *DoltDB) GC(ctx context.Context, uncommitedVals ...hash.Hash) error {
 	}
 
 	datasets, err := ddb.db.Datasets(ctx)
+	if err != nil {
+		return err
+	}
 	newGen := hash.NewHashSet(uncommitedVals...)
 	oldGen := make(hash.HashSet)
-	err = datasets.IterAll(ctx, func(key, value types.Value) error {
-		keyStr := string(key.(types.String))
-		h := value.(types.Ref).TargetHash()
-
+	err = datasets.IterAll(ctx, func(keyStr string, h hash.Hash) error {
 		var isOldGen bool
 		switch {
 		case ref.IsRef(keyStr):
@@ -1204,6 +1238,10 @@ func (ddb *DoltDB) GC(ctx context.Context, uncommitedVals ...hash.Hash) error {
 	return collector.GC(ctx, oldGen, newGen)
 }
 
+func (ddb *DoltDB) ShallowGC(ctx context.Context) error {
+	return datas.PruneTableFiles(ctx, ddb.db)
+}
+
 func (ddb *DoltDB) pruneUnreferencedDatasets(ctx context.Context) error {
 	dd, err := ddb.db.Datasets(ctx)
 	if err != nil {
@@ -1211,12 +1249,11 @@ func (ddb *DoltDB) pruneUnreferencedDatasets(ctx context.Context) error {
 	}
 
 	var deletes []string
-	_ = dd.Iter(ctx, func(ds, _ types.Value) (stop bool, err error) {
-		dsID := string(ds.(types.String))
+	_ = dd.IterAll(ctx, func(dsID string, _ hash.Hash) (err error) {
 		if !ref.IsRef(dsID) && !ref.IsWorkingSet(dsID) {
 			deletes = append(deletes, dsID)
 		}
-		return false, nil
+		return nil
 	})
 
 	// e.g. flushes
@@ -1239,13 +1276,20 @@ func (ddb *DoltDB) pruneUnreferencedDatasets(ctx context.Context) error {
 	return nil
 }
 
-// PushChunks initiates a push into a database from the source database given, at the Value ref given. Pull progress is
-// communicated over the provided channel.
-func (ddb *DoltDB) PushChunks(ctx context.Context, tempDir string, srcDB *DoltDB, rf types.Ref, progChan chan datas.PullProgress, pullerEventCh chan datas.PullerEvent) error {
-	if datas.CanUsePuller(srcDB.db) && datas.CanUsePuller(ddb.db) {
-		puller, err := datas.NewPuller(ctx, tempDir, defaultChunksPerTF, srcDB.db, ddb.db, rf.TargetHash(), pullerEventCh)
+// PullChunks initiates a pull into this database from the source database
+// given, pulling all chunks reachable from the given targetHash. Pull progress
+// is communicated over the provided channel.
+func (ddb *DoltDB) PullChunks(ctx context.Context, tempDir string, srcDB *DoltDB, targetHash hash.Hash, progChan chan pull.PullProgress, pullerEventCh chan pull.PullerEvent) error {
+	srcCS := datas.ChunkStoreFromDatabase(srcDB.db)
+	destCS := datas.ChunkStoreFromDatabase(ddb.db)
+	wrf, err := types.WalkRefsForChunkStore(srcCS)
+	if err != nil {
+		return err
+	}
 
-		if err == datas.ErrDBUpToDate {
+	if datas.CanUsePuller(srcDB.db) && datas.CanUsePuller(ddb.db) {
+		puller, err := pull.NewPuller(ctx, tempDir, defaultChunksPerTF, srcCS, destCS, wrf, targetHash, pullerEventCh)
+		if err == pull.ErrDBUpToDate {
 			return nil
 		} else if err != nil {
 			return err
@@ -1253,52 +1297,21 @@ func (ddb *DoltDB) PushChunks(ctx context.Context, tempDir string, srcDB *DoltDB
 
 		return puller.Pull(ctx)
 	} else {
-		return datas.Pull(ctx, srcDB.db, ddb.db, rf, progChan)
+		return pull.Pull(ctx, srcCS, destCS, wrf, targetHash, progChan)
 	}
 }
 
-func (ddb *DoltDB) PushChunksForRefHash(ctx context.Context, tempDir string, srcDB *DoltDB, h hash.Hash, pullerEventCh chan datas.PullerEvent) error {
-	if datas.CanUsePuller(srcDB.db) && datas.CanUsePuller(ddb.db) {
-		puller, err := datas.NewPuller(ctx, tempDir, defaultChunksPerTF, srcDB.db, ddb.db, h, pullerEventCh)
-
-		if err == datas.ErrDBUpToDate {
-			return nil
-		} else if err != nil {
-			return err
-		}
-
-		return puller.Pull(ctx)
-	} else {
-		return errors.New("this type of chunk store does not support this operation")
-	}
+func (ddb *DoltDB) Clone(ctx context.Context, destDB *DoltDB, eventCh chan<- pull.TableFileEvent) error {
+	return pull.Clone(ctx, datas.ChunkStoreFromDatabase(ddb.db), datas.ChunkStoreFromDatabase(destDB.db), eventCh)
 }
 
-// PullChunks initiates a pull into a database from the source database given, at the commit given. Progress is
-// communicated over the provided channel.
-func (ddb *DoltDB) PullChunks(ctx context.Context, tempDir string, srcDB *DoltDB, stRef types.Ref, progChan chan datas.PullProgress, pullerEventCh chan datas.PullerEvent) error {
-	if datas.CanUsePuller(srcDB.db) && datas.CanUsePuller(ddb.db) {
-		puller, err := datas.NewPuller(ctx, tempDir, defaultChunksPerTF, srcDB.db, ddb.db, stRef.TargetHash(), pullerEventCh)
-		if err != nil {
-			return err
-		}
-
-		return puller.Pull(ctx)
-	} else {
-		return datas.PullWithoutBatching(ctx, srcDB.db, ddb.db, stRef, progChan)
-	}
-}
-
-func (ddb *DoltDB) Clone(ctx context.Context, destDB *DoltDB, eventCh chan<- datas.TableFileEvent) error {
-	return datas.Clone(ctx, ddb.db, destDB.db, eventCh)
-}
-
-func (ddb *DoltDB) SetCommitHooks(ctx context.Context, postHooks []datas.CommitHook) *DoltDB {
+func (ddb *DoltDB) SetCommitHooks(ctx context.Context, postHooks []CommitHook) *DoltDB {
 	ddb.db = ddb.db.SetCommitHooks(ctx, postHooks)
 	return ddb
 }
 
 func (ddb *DoltDB) SetCommitHookLogger(ctx context.Context, wr io.Writer) *DoltDB {
-	if ddb.db != nil {
+	if ddb.db.Database != nil {
 		ddb.db = ddb.db.SetCommitHookLogger(ctx, wr)
 	}
 	return ddb
