@@ -316,45 +316,45 @@ func testFindCommonChronologicalType(t *testing.T) {
 
 var oneOfEachKindCSVStr = `uuid,int,uint,float,bool,string
 00000000-0000-0000-0000-000000000000,-4,9223372036854775810,-4.1,true,this is
-00000000-0000-0000-0000-000000000001,-3,9223372036854775810,-3.2,false,a test
-00000000-0000-0000-0000-000000000002,-2,9223372036854775810,-2.3,TRUE,anything could
-00000000-0000-0000-0000-000000000003,-1,9223372036854775810,-1.4,FALSE,be written
-00000000-0000-0000-0000-000000000004,0,9223372036854775810,0.0,true,in these
-00000000-0000-0000-0000-000000000005,1,9223372036854775810,1.5,false,string
-00000000-0000-0000-0000-000000000006,2,9223372036854775810,2.6,TRUE,columns.
-00000000-0000-0000-0000-000000000007,3,9223372036854775810,3.7,FALSE,Even emojis
-00000000-0000-0000-0000-000000000008,4,9223372036854775810,4.8,true,🐈🐈🐈🐈`
+f3c600cd-74d3-4c2d-b5a5-88934e7c6018,-3,9223372036854775810,-3.2,false,a test
+0b4fe00e-c690-4fbe-b014-b07f236cd7fd,-2,9223372036854775810,-2.3,TRUE,anything could
+7d85f566-4b60-4cc0-a029-cfb679c3fd8b,-1,9223372036854775810,-1.4,FALSE,be written
+df017641-5e4b-4ef5-9f7a-9e9f2ce044b3,0,9223372036854775810,0.0,true,in these
+4b4fb1af-0701-48dc-8593-aa7e094e72cc,1,9223372036854775810,1.5,false,string
+b97b7e95-c811-4327-8f75-8358595e9614,2,9223372036854775810,2.6,TRUE,columns.
+68d7b8bb-9065-47a8-9302-d4d44e5a149d,3,9223372036854775810,3.7,FALSE,Even emojis
+5b6b7354-f89e-44b2-9058-8aea7f17d5fb,4,9223372036854775810,4.8,true,🐈🐈🐈🐈`
 
 var oneOfEachKindWithSomeNilsCSVStr = `uuid,int,uint,float,bool,string
-00000000-0000-0000-0000-000000000000,-4,9223372036854775810,-4.1,true,this is
-00000000-0000-0000-0000-000000000001,-3,9223372036854775810,-3.2,false,a test
-00000000-0000-0000-0000-000000000002,,9223372036854775810,-2.3,TRUE,anything could
-00000000-0000-0000-0000-000000000003,-1,9223372036854775810,-1.4,FALSE,be written
-00000000-0000-0000-0000-000000000004,0,9223372036854775810,0.0,true,in these
-00000000-0000-0000-0000-000000000005,1,9223372036854775810,1.5,false,string
-00000000-0000-0000-0000-000000000006,,9223372036854775810,2.6,TRUE,columns.
-00000000-0000-0000-0000-000000000007,3,9223372036854775810,3.7,FALSE,Even emojis
-00000000-0000-0000-0000-000000000008,4,9223372036854775810,4.8,true,🐈🐈🐈🐈`
+6a52205c-2a46-4b04-9567-9e8707054774,-4,9223372036854775810,-4.1,true,this is
+3975299d-71cf-4faa-afea-155d64bd1a9b,-3,9223372036854775810,-3.2,false,a test
+8b682886-0ad7-4b96-a300-48fc1e10032e,,9223372036854775810,-2.3,TRUE,anything could
+5da4b68c-58b1-41f9-8fed-4fbe15740b79,-1,9223372036854775810,-1.4,FALSE,be written
+c659a238-3516-4380-a443-e528e55eb1bd,0,9223372036854775810,0.0,true,in these
+86f3bb91-7476-48a1-8d14-6249cc696b02,1,9223372036854775810,1.5,false,string
+42f2b05d-c279-4058-a13a-58f81a867401,,9223372036854775810,2.6,TRUE,columns.
+935afaea-af2a-4cc9-b008-505a5edbeb3e,3,9223372036854775810,3.7,FALSE,Even emojis
+aab7b641-124e-4193-8837-97cdfb13e8c4,4,9223372036854775810,4.8,true,🐈🐈🐈🐈`
 
 var mixUintsAndPositiveInts = `uuid,mix
-00000000-0000-0000-0000-000000000000,9223372036854775810
-00000000-0000-0000-0000-000000000001,0
-00000000-0000-0000-0000-000000000002,1000000`
+95e8ccf4-78a7-479e-a974-cf8605e6b01d,9223372036854775810
+60d6b5f9-9c99-4165-a835-1159e54b82ca,0
+cab7f39d-e1f2-46f8-b858-372067ec75a0,1000000`
 
 var floatsWithZeroForFractionalPortion = `uuid,float
-00000000-0000-0000-0000-000000000000,0.0
-00000000-0000-0000-0000-000000000001,-1.0
-00000000-0000-0000-0000-000000000002,1.0`
+61c8e0ea-f2ff-49f8-98b8-df8142fd8a94,0.0
+e5a3bdca-9315-4afe-b548-6e44924ff549,-1.0
+e6b09e59-d524-4417-8252-f5c3eeeb5033,1.0`
 
 var floatsWithLargeFractionalPortion = `uuid,float
-00000000-0000-0000-0000-000000000000,0.0
-00000000-0000-0000-0000-000000000001,-1.0
-00000000-0000-0000-0000-000000000002,1.0`
+ed929281-b4d0-4631-b931-8c2ebfb4ba84,0.0
+7d7c9b56-301c-4aa0-9034-8e12315b35cf,-1.0
+76bbed0b-7479-45bb-9813-ff1383bccee6,1.0`
 
 var floatsWithTinyFractionalPortion = `uuid,float
-00000000-0000-0000-0000-000000000000,0.0001
-00000000-0000-0000-0000-000000000001,-1.0005
-00000000-0000-0000-0000-000000000002,1.0001`
+da95f30d-4cde-4e53-a786-e00624ff2cbe,0.0001
+6fb474ca-8bec-4e21-9af2-a1ba22f39f1d,-1.0005
+aee125d4-e055-42e9-af3d-0bc676436ccd,1.0001`
 
 var identityMapper = make(rowconv.NameMapper)
 
