@@ -81,7 +81,6 @@ func TestBasics(t *testing.T) {
 		expectedIsFileType bool
 	}{
 		{NewDataLocation("", ".csv"), "stream", false},
-		{NewDataLocation(testTableName, ""), DoltDB.ReadableStr() + ":" + testTableName, false},
 		{NewDataLocation("file.csv", ""), CsvFile.ReadableStr() + ":file.csv", true},
 		{NewDataLocation("file.psv", ""), PsvFile.ReadableStr() + ":file.psv", true},
 		{NewDataLocation("file.json", ""), JsonFile.ReadableStr() + ":file.json", true},
@@ -129,7 +128,6 @@ func init() {
 
 func TestExists(t *testing.T) {
 	testLocations := []DataLocation{
-		NewDataLocation(testTableName, ""),
 		NewDataLocation("file.csv", ""),
 		NewDataLocation("file.psv", ""),
 		NewDataLocation("file.json", ""),
@@ -146,11 +144,7 @@ func TestExists(t *testing.T) {
 				t.Error("Shouldn't exist before creation")
 			}
 
-			if tableVal, isTable := loc.(TableDataLocation); isTable {
-				var err error
-				root, err = root.CreateEmptyTable(context.Background(), tableVal.Name, fakeSchema)
-				assert.NoError(t, err)
-			} else if fileVal, isFile := loc.(FileDataLocation); isFile {
+			if fileVal, isFile := loc.(FileDataLocation); isFile {
 				err := fs.WriteFile(fileVal.Path, []byte("test"))
 				assert.NoError(t, err)
 			}
@@ -214,7 +208,7 @@ func TestCreateRdWr(t *testing.T) {
 			t.Fatal("Unexpected error opening file for writer.", wrErr)
 		}
 
-		wr, wErr := loc.NewCreatingWriter(context.Background(), mvOpts, root, true, fakeSchema, nil, opts, writer)
+		wr, wErr := loc.NewCreatingWriter(context.Background(), mvOpts, root, fakeSchema, opts, writer)
 		if wErr != nil {
 			t.Fatal("Unexpected error creating writer.", wErr)
 		}
@@ -232,11 +226,6 @@ func TestCreateRdWr(t *testing.T) {
 			t.Fatal("Failed to write data. bad:", numBad, err)
 		}
 
-		if wr, ok := wr.(DataMoverCloser); ok {
-			root, err = wr.Flush(context.Background())
-			assert.NoError(t, err)
-		}
-
 		rd, _, err := loc.NewReader(context.Background(), root, dEnv.FS, JSONOptions{TableName: testTableName, SchFile: testSchemaFileName})
 
 		if err != nil {
