@@ -123,6 +123,14 @@ func addColumnToSchema(
 	}
 	newSch.Indexes().AddIndex(sch.Indexes().AllIndexes()...)
 
+	// Copy over all checks from the old schema
+	for _, check := range sch.Checks().AllChecks() {
+		_, err := newSch.Checks().AddCheck(check.Name(), check.Expression(), check.Enforced())
+		if err != nil {
+			return nil, err
+		}
+	}
+
 	pkOrds, err := modifyPkOrdinals(sch, newSch)
 	if err != nil {
 		return nil, err
