@@ -1327,7 +1327,7 @@ func TestMergeableIndexes(t *testing.T) {
 
 			_, iter, err := engine.Query(sqlCtx, query)
 			require.NoError(t, err)
-			res, err := sql.RowIterToRows(sqlCtx, iter)
+			res, err := sql.RowIterToRows(sqlCtx, nil, iter)
 			require.NoError(t, err)
 
 			if assert.Equal(t, len(test.pks), len(res)) {
@@ -1543,7 +1543,7 @@ func TestMergeableIndexesNulls(t *testing.T) {
 			_, iter, err := engine.Query(sqlCtx, query)
 			require.NoError(t, err)
 
-			res, err := sql.RowIterToRows(sqlCtx, iter)
+			res, err := sql.RowIterToRows(sqlCtx, nil, iter)
 			require.NoError(t, err)
 			if assert.Equal(t, len(test.pks), len(res)) {
 				for i, pk := range test.pks {
