@@ -41,6 +41,7 @@ import (
 	"github.com/dolthub/dolt/go/libraries/doltcore/table/editor"
 	"github.com/dolthub/dolt/go/libraries/doltcore/table/editor/creation"
 	"github.com/dolthub/dolt/go/store/hash"
+	"github.com/dolthub/dolt/go/store/prolly"
 	"github.com/dolthub/dolt/go/store/types"
 )
 
@@ -271,36 +272,13 @@ func (t *DoltTable) Partitions(ctx *sql.Context) (sql.PartitionIter, error) {
 		return nil, err
 	}
 
-	rowData, err := table.GetRowData(ctx)
+	rows, err := table.GetRowData(ctx)
 	if err != nil {
 		return nil, err
 	}
+	partitions := partitionsFromRows(ctx, rows)
 
-	numElements := rowData.Count()
-	if numElements == 0 {
-		return newDoltTablePartitionIter(rowData, doltTablePartition{0, 0, rowData}), nil
-	}
-
-	itemsPerPartition := MaxRowsPerPartition
-	numPartitions := (numElements / itemsPerPartition) + 1
-	if numPartitions < uint64(partitionMultiplier*runtime.NumCPU()) {
-		itemsPerPartition = numElements / uint64(partitionMultiplier*runtime.NumCPU())
-
-		if itemsPerPartition == 0 {
-			itemsPerPartition = numElements
-			numPartitions = 1
-		} else {
-			numPartitions = (numElements / itemsPerPartition) + 1
-		}
-	}
-
-	partitions := make([]doltTablePartition, numPartitions)
-	for i := uint64(0); i < numPartitions-1; i++ {
-		partitions[i] = doltTablePartition{i * itemsPerPartition, (i + 1) * itemsPerPartition, rowData}
-	}
-	partitions[numPartitions-1] = doltTablePartition{(numPartitions - 1) * itemsPerPartition, numElements, rowData}
-
-	return newDoltTablePartitionIter(rowData, partitions...), nil
+	return newDoltTablePartitionIter(rows, partitions...), nil
 }
 
 func (t *DoltTable) IsTemporary() bool {
@@ -370,10 +348,6 @@ func (t *DoltTable) PartitionRows(ctx *sql.Context, partition sql.Partition) (sq
 func partitionRows(ctx *sql.Context, t *doltdb.Table, projCols []string, partition sql.Partition) (sql.RowIter, error) {
 	switch typedPartition := partition.(type) {
 	case doltTablePartition:
-		if typedPartition.end == 0 {
-			return emptyRowIterator{}, nil
-		}
-
 		return newRowIterator(ctx, t, projCols, typedPartition)
 	case index.SinglePartition:
 		return newRowIterator(ctx, t, projCols, doltTablePartition{rowData: typedPartition.RowData, end: NoUpperBound})
@@ -504,15 +478,18 @@ func (t *WritableDoltTable) Truncate(ctx *sql.Context) (int, error) {
 		return 0, err
 	}
 	numOfRows := int(rowData.Count())
-	empty, err := types.NewMap(ctx, table.ValueReadWriter())
+
+	empty, err := durable.NewEmptyIndex(ctx, table.ValueReadWriter(), t.sch)
 	if err != nil {
 		return 0, err
 	}
+
 	// truncate table resets auto-increment value
 	newTable, err := doltdb.NewTable(ctx, table.ValueReadWriter(), t.sch, empty, nil, nil)
 	if err != nil {
 		return 0, err
 	}
+
 	newTable, err = editor.RebuildAllIndexes(ctx, newTable, t.opts)
 	if err != nil {
 		return 0, err
@@ -705,13 +682,98 @@ var _ sql.Partition = doltTablePartition{}
 const NoUpperBound = 0xffffffffffffffff
 
 type doltTablePartition struct {
-	// start is the first index of this partition (inclusive)
-	start uint64
-	// all elements in the partition will be less than end (exclusive)
-	end     uint64
+	// half-open index range of partition: [start, end)
+	start, end uint64
+
+	// value range of partition for "prolly" implementation
+	rowRange prolly.Range
+
 	rowData durable.Index
 }
 
+func partitionsFromRows(ctx context.Context, rows durable.Index) []doltTablePartition {
+	if rows.Empty() {
+		return []doltTablePartition{
+			{start: 0, end: 0, rowData: rows},
+		}
+	}
+
+	nbf := rows.Format()
+	switch nbf {
+	case types.Format_LD_1, types.Format_7_18:
+		nm := durable.NomsMapFromIndex(rows)
+		return partitionsFromNomsRows(nm, durable.VrwFromNomsIndex(rows))
+
+	case types.Format_DOLT_1:
+		return partitionsFromProllyRows(rows)
+	}
+
+	return nil
+}
+
+func partitionsFromNomsRows(rows types.Map, vrw types.ValueReadWriter) []doltTablePartition {
+	numElements := rows.Len()
+	itemsPerPartition := MaxRowsPerPartition
+	numPartitions := (numElements / itemsPerPartition) + 1
+
+	if numPartitions < uint64(partitionMultiplier*runtime.NumCPU()) {
+		itemsPerPartition = numElements / uint64(partitionMultiplier*runtime.NumCPU())
+		if itemsPerPartition == 0 {
+			itemsPerPartition = numElements
+			numPartitions = 1
+		} else {
+			numPartitions = (numElements / itemsPerPartition) + 1
+		}
+	}
+
+	partitions := make([]doltTablePartition, numPartitions)
+	for i := uint64(0); i < numPartitions-1; i++ {
+		partitions[i] = doltTablePartition{
+			start:   i * itemsPerPartition,
+			end:     (i + 1) * itemsPerPartition,
+			rowData: durable.IndexFromNomsMap(rows, vrw),
+		}
+	}
+
+	partitions[numPartitions-1] = doltTablePartition{
+		start:   (numPartitions - 1) * itemsPerPartition,
+		end:     numElements,
+		rowData: durable.IndexFromNomsMap(rows, vrw),
+	}
+
+	return partitions
+}
+
+func partitionsFromProllyRows(rows durable.Index) []doltTablePartition {
+	pm := durable.ProllyMapFromIndex(rows)
+	keyDesc, _ := pm.Descriptors()
+
+	// naively divide map by top-level keys
+	keys := prolly.PartitionKeysFromMap(pm)
+
+	first := prolly.Range{
+		Start:   prolly.RangeCut{Unbound: true},
+		Stop:    prolly.RangeCut{Key: keys[0], Inclusive: true},
+		KeyDesc: keyDesc,
+	}
+
+	parts := make([]doltTablePartition, len(keys))
+	parts[0] = doltTablePartition{rowRange: first, rowData: rows}
+	for i := range parts {
+		if i == 0 {
+			continue
+		}
+		rng := prolly.Range{
+			Start:   prolly.RangeCut{Key: keys[i-1], Inclusive: false},
+			Stop:    prolly.RangeCut{Key: keys[i], Inclusive: true},
+			KeyDesc: keyDesc,
+		}
+		parts[i] = doltTablePartition{rowRange: rng, rowData: rows}
+	}
+
+	return parts
+}
+
 // Key returns the key for this partition, which must uniquely identity the partition.
 func (p doltTablePartition) Key() []byte {
 	return []byte(strconv.FormatUint(p.start, 10) + " >= i < " + strconv.FormatUint(p.end, 10))
@@ -978,10 +1040,7 @@ func (t *AlterableDoltTable) ModifyColumn(ctx *sql.Context, columnName string, c
 
 		initialValue := column.Type.Zero()
 
-		colIdx, err := updatedSch.GetAllCols().IndexOf(columnName)
-		if err != nil {
-			return err
-		}
+		colIdx := updatedSch.GetAllCols().IndexOf(columnName)
 
 		rowData, err := updatedTable.GetRowData(ctx)
 		if err != nil {
@@ -1134,6 +1193,10 @@ func (t *AlterableDoltTable) CreateIndex(
 
 // DropIndex implements sql.IndexAlterableTable
 func (t *AlterableDoltTable) DropIndex(ctx *sql.Context, indexName string) error {
+	if types.IsFormat_DOLT_1(t.nbf) {
+		return nil
+	}
+
 	// We disallow removing internal dolt_ tables from SQL directly
 	if strings.HasPrefix(indexName, "dolt_") {
 		return fmt.Errorf("dolt internal indexes may not be dropped")
@@ -1220,7 +1283,13 @@ func (t *AlterableDoltTable) CreateForeignKey(
 	columns []string,
 	refTblName string,
 	refColumns []string,
-	onUpdate, onDelete sql.ForeignKeyReferenceOption) error {
+	onUpdate, onDelete sql.ForeignKeyReferenceOption,
+) error {
+	if types.IsFormat_DOLT_1(t.nbf) {
+		// todo(andy)
+		return nil
+	}
+
 	if fkName != "" && !doltdb.IsValidForeignKeyName(fkName) {
 		return fmt.Errorf("invalid foreign key name `%s` as it must match the regular expression %s", fkName, doltdb.ForeignKeyNameRegexStr)
 	}
@@ -1298,6 +1367,11 @@ func (t *AlterableDoltTable) CreateForeignKey(
 
 // DropForeignKey implements sql.ForeignKeyAlterableTable
 func (t *AlterableDoltTable) DropForeignKey(ctx *sql.Context, fkName string) error {
+	if types.IsFormat_DOLT_1(t.nbf) {
+		// todo(andy)
+		return nil
+	}
+
 	root, err := t.getRoot(ctx)
 	if err != nil {
 		return err
@@ -1488,7 +1562,7 @@ func createIndexForTable(
 		if err != nil {
 			return nil, err
 		}
-		newTable, err = newTable.SetIndexRowData(ctx, index.Name(), indexRowData)
+		newTable, err = newTable.SetNomsIndexRows(ctx, index.Name(), indexRowData)
 		if err != nil {
 			return nil, err
 		}
@@ -1756,7 +1830,7 @@ func (t *AlterableDoltTable) DropPrimaryKey(ctx *sql.Context) error {
 		return err
 	}
 
-	// Update the root with then new table
+	// Update the root with the new table
 	newRoot, err = newRoot.PutTable(ctx, t.tableName, table)
 	if err != nil {
 		return err
