@@ -33,6 +33,15 @@ import (
 	"github.com/dolthub/dolt/go/store/types"
 )
 
+type DatasetsMap interface {
+	// How many datasets are in the map
+	Len() uint64
+
+	IterAll(ctx context.Context, cb func(id string, addr hash.Hash) error) error
+
+	toNomsMap() (types.Map, bool)
+}
+
 // Database provides versioned storage for noms values. While Values can be
 // directly read and written from a Database, it is generally more appropriate
 // to read data by inspecting the Head of a Dataset and write new data by
@@ -43,66 +52,35 @@ import (
 // Datasets() occurring after a call to Commit() (et al) will represent the
 // result of the Commit().
 type Database interface {
-	// To implement types.ValueWriter, Database implementations provide
-	// WriteValue(). WriteValue() writes v to this Database, though v is not
-	// guaranteed to be be persistent until after a subsequent Commit(). The
-	// return value is the Ref of v.
-	// Written values won't be persisted until a commit-alike
-	types.ValueReadWriter
-
 	// Close must have no side-effects
 	io.Closer
 
 	// Datasets returns the root of the database which is a
 	// Map<String, Ref<Commit>> where string is a datasetID.
-	Datasets(ctx context.Context) (types.Map, error)
+	Datasets(ctx context.Context) (DatasetsMap, error)
 
 	// GetDataset returns a Dataset struct containing the current mapping of
 	// datasetID in the above Datasets Map.
 	GetDataset(ctx context.Context, datasetID string) (Dataset, error)
 
-	// Rebase brings this Database's view of the world inline with upstream.
-	Rebase(ctx context.Context) error
-
 	// Commit updates the Commit that ds.ID() in this database points at. All
 	// Values that have been written to this Database are guaranteed to be
-	// persistent after Commit() returns.
-	// The new Commit struct is constructed using v, opts.Parents, and
-	// opts.Meta. If opts.Parents is the zero value (types.Set{}) then
-	// the current head is used. If opts.Meta is the zero value
-	// (types.Struct{}) then a fully initialized empty Struct is passed to
-	// NewCommit.
-	// The returned Dataset is always the newest snapshot, regardless of
-	// success or failure, and Datasets() is updated to match backing storage
-	// upon return as well. If the update cannot be performed, e.g., because
-	// of a conflict, Commit returns an 'ErrMergeNeeded' error.
+	// persistent after Commit() returns successfully.
+	//
+	// The new Commit struct is constructed using v, opts.ParentsList, and
+	// opts.Meta. If opts.ParentsList is empty then the head value from
+	// |ds| is used as the parent. If opts.Meta is the zero value the
+	// Commit struct as an empty Meta struct.
+	//
+	// If the update cannot be performed because the existing dataset head
+	// is not a common ancestor of the constructed commit struct, returns
+	// an 'ErrMergeNeeded' error.
 	Commit(ctx context.Context, ds Dataset, v types.Value, opts CommitOptions) (Dataset, error)
 
-	// CommitDangling creates a new commit that is unreferenced by any Dataset.
-	// This method is used in the course of programmatic updates such as Rebase
-	// All Values that have been written to this Database are guaranteed to be
-	// persistent after CommitDangling() returns.
-	// The new Commit struct is of the same form as structs created by Commit()
-	CommitDangling(ctx context.Context, v types.Value, opts CommitOptions) (types.Struct, error)
-
-	// CommitValue updates the Commit that ds.ID() in this database points at.
-	// All Values that have been written to this Database are guaranteed to be
-	// persistent after Commit().
-	// The new Commit struct is constructed using `v`, and the current Head of
-	// `ds` as the lone Parent.
-	// The returned Dataset is always the newest snapshot, regardless of
-	// success or failure, and Datasets() is updated to match backing storage
-	// upon return as well. If the update cannot be performed, e.g., because
-	// of a conflict, Commit returns an 'ErrMergeNeeded' error.
-	CommitValue(ctx context.Context, ds Dataset, v types.Value) (Dataset, error)
-
-	// Tag stores an immutable reference to a Value. It takes a Ref and a Dataset
-	// whose head must be nil (ie a newly created Dataset).
-	// The new Tag struct is constructed with `ref` and metadata about the tag
+	// Tag stores an immutable reference to a Commit. It takes a Ref and a
+	// Dataset whose head must be nil (ie a newly created Dataset).  The
+	// new Tag struct is constructed with `ref` and metadata about the tag
 	// contained in the struct `opts.Meta`.
-	// The returned Dataset is always the newest snapshot, regardless of
-	// success or failure, and Datasets() is updated to match backing storage
-	// upon return as well.
 	Tag(ctx context.Context, ds Dataset, ref types.Ref, opts TagOptions) (Dataset, error)
 
 	// UpdateWorkingSet updates the dataset given, setting its value to a new
@@ -122,24 +100,22 @@ type Database interface {
 	CommitWithWorkingSet(ctx context.Context, commitDS, workingSetDS Dataset, commit types.Value, workingSetSpec WorkingSetSpec, prevWsHash hash.Hash, opts CommitOptions) (Dataset, Dataset, error)
 
 	// Delete removes the Dataset named ds.ID() from the map at the root of
-	// the Database. The Dataset data is not necessarily cleaned up at this
-	// time, but may be garbage collected in the future.
-	// The returned Dataset is always the newest snapshot, regardless of
-	// success or failure, and Datasets() is updated to match backing storage
-	// upon return as well. If the update cannot be performed, e.g., because
-	// of a conflict, Delete returns an 'ErrMergeNeeded' error.
+	// the Database. If the Dataset is already not present in the map,
+	// returns success.
+	//
+	// If the update cannot be performed, e.g., because of a conflict,
+	// Delete returns an 'ErrMergeNeeded' error.
 	Delete(ctx context.Context, ds Dataset) (Dataset, error)
 
-	// SetHead ignores any lineage constraints (e.g. the current Head being in
-	// commit’s Parent set) and force-sets a mapping from datasetID: commit in
-	// this database.
-	// All Values that have been written to this Database are guaranteed to be
-	// persistent after SetHead(). If the update cannot be performed, e.g.,
-	// because another process moved the current Head out from under you,
-	// error will be non-nil.
-	// The newest snapshot of the Dataset is always returned, so the caller an
-	// easily retry using the latest.
-	// Regardless, Datasets() is updated to match backing storage upon return.
+	// SetHead ignores any lineage constraints (e.g. the current head being
+	// an ancestor of the new Commit) and force-sets a mapping from
+	// datasetID: newHeadRef in this database. newHeadRef can point to a
+	// Commit or a Tag, but if Dataset is already present in the Database,
+	// it must point to the type of struct.
+	//
+	// All values that have been written to this Database are guaranteed to be
+	// persistent after SetHead(). If the update cannot be performed, error
+	// will be non-nil.
 	SetHead(ctx context.Context, ds Dataset, newHeadRef types.Ref) (Dataset, error)
 
 	// FastForward takes a types.Ref to a Commit object and makes it the new
@@ -147,9 +123,6 @@ type Database interface {
 	// used e.g. after a call to Pull(). If the update cannot be performed,
 	// e.g., because another process moved the current Head out from under
 	// you, err will be non-nil.
-	// The newest snapshot of the Dataset is always returned, so the caller
-	// can easily retry using the latest.
-	// Regardless, Datasets() is updated to match backing storage upon return.
 	FastForward(ctx context.Context, ds Dataset, newHeadRef types.Ref) (Dataset, error)
 
 	// Stats may return some kind of struct that reports statistics about the
@@ -162,38 +135,22 @@ type Database interface {
 	// if this operation is not supported.
 	StatsSummary() string
 
-	Flush(ctx context.Context) error
-
 	// chunkStore returns the ChunkStore used to read and write
 	// groups of values to the database efficiently. This interface is a low-
 	// level detail of the database that should infrequently be needed by
 	// clients.
 	chunkStore() chunks.ChunkStore
-
-	// SetCommitHooks attaches a list of CommitHook that can be executed
-	// after CommitWithWorkingSet
-	SetCommitHooks(context.Context, []CommitHook) *database
-
-	// WithCommitHookLogger passes an error handler from the user-facing session
-	// to a commit hook executed at the datas layer
-	SetCommitHookLogger(context.Context, io.Writer) *database
-
-	// ExecuteCommitHooks calls each database hook with the given Dataset
-	ExecuteCommitHooks(context.Context, Dataset)
-
-	// NomsRoot returns the hash of the toplevel noms dataset map
-	NomsRoot(context.Context) (hash.Hash, error)
-
-	// CommitRoot executes a chunkStore commit, atomically swapping the root hash of the database manifest
-	CommitRoot(ctx context.Context, current, last hash.Hash) (bool, error)
 }
 
 func NewDatabase(cs chunks.ChunkStore) Database {
-	return newDatabase(cs)
+	return newDatabase(types.NewValueStore(cs))
 }
 
-// GarbageCollector provides a method to
-// remove unreferenced data from a store.
+func NewTypesDatabase(vs *types.ValueStore) Database {
+	return newDatabase(vs)
+}
+
+// GarbageCollector provides a method to remove unreferenced data from a store.
 type GarbageCollector interface {
 	types.ValueReadWriter
 
@@ -217,3 +174,7 @@ func GetCSStatSummaryForDB(db Database) string {
 	cs := db.chunkStore()
 	return cs.StatsSummary()
 }
+
+func ChunkStoreFromDatabase(db Database) chunks.ChunkStore {
+	return db.chunkStore()
+}
