@@ -36,7 +36,6 @@ import (
 	flag "github.com/juju/gnuflag"
 
 	"github.com/dolthub/dolt/go/store/d"
-	"github.com/dolthub/dolt/go/store/datas"
 	"github.com/dolthub/dolt/go/store/hash"
 	"github.com/dolthub/dolt/go/store/nbs"
 	"github.com/dolthub/dolt/go/store/types"
@@ -58,6 +57,8 @@ func main() {
 		flag.PrintDefaults()
 	}
 
+	ctx := context.Background()
+
 	profile.RegisterProfileFlags(flag.CommandLine)
 	flag.Parse(true)
 
@@ -69,7 +70,7 @@ func main() {
 	var store *nbs.NomsBlockStore
 	if *dir != "" {
 		var err error
-		store, err = nbs.NewLocalStore(context.Background(), types.Format_Default.VersionString(), *dir, memTableSize)
+		store, err = nbs.NewLocalStore(ctx, types.Format_Default.VersionString(), *dir, memTableSize)
 		d.PanicIfError(err)
 
 		*dbName = *dir
@@ -83,19 +84,23 @@ func main() {
 		log.Fatalf("Must set either --dir or ALL of --table, --bucket and --db\n")
 	}
 
-	db := datas.NewDatabase(store)
-	defer db.Close()
-
-	defer profile.MaybeStartProfile().Stop()
-
-	dss, err := db.Datasets(context.Background())
+	vrw := types.NewValueStore(store)
 
+	root, err := store.Root(ctx)
 	if err != nil {
-		fmt.Fprintln(os.Stderr, "error: failed to get datasets")
+		fmt.Fprintf(os.Stderr, "error: failed to get root: %v\n", err)
 		os.Exit(1)
 	}
 
-	ref, err := types.NewRef(dss, types.Format_Default)
+	defer profile.MaybeStartProfile().Stop()
+
+	rootValue, err := vrw.ReadValue(ctx, root)
+	if err != nil {
+		fmt.Fprintf(os.Stderr, "error: failed to get root value: %v\n", err)
+		os.Exit(1)
+	}
+
+	ref, err := types.NewRef(rootValue, types.Format_Default)
 	d.PanicIfError(err)
 	height := ref.Height()
 	fmt.Println("Store is of height", height)
@@ -106,18 +111,11 @@ func main() {
 	var optimal, sum int
 	visited := map[hash.Hash]bool{}
 
-	root, err := store.Root(context.Background())
-
-	if err != nil {
-		fmt.Fprintln(os.Stderr, "error: failed to get root")
-		os.Exit(1)
-	}
-
 	current := hash.HashSlice{root}
 	for numNodes := 1; numNodes > 0; numNodes = len(current) {
 		// Start by reading the values of the current level of the graph
 		currentValues := make(map[hash.Hash]types.Value, len(current))
-		readValues, err := db.ReadManyValues(context.Background(), current)
+		readValues, err := vrw.ReadManyValues(ctx, current)
 		d.PanicIfError(err)
 		for i, v := range readValues {
 			h := current[i]
