@@ -56,6 +56,9 @@ const (
 	TimestampKind
 	DecimalKind
 	JSONKind
+	PointKind
+	LinestringKind
+	PolygonKind
 
 	UnknownKind NomsKind = 255
 )
@@ -83,6 +86,9 @@ func init() {
 	KindToType[TimestampKind] = Timestamp{}
 	KindToType[DecimalKind] = Decimal{}
 	KindToType[JSONKind] = JSON{}
+	KindToType[PointKind] = Point{}
+	KindToType[LinestringKind] = Linestring{}
+	KindToType[PolygonKind] = Polygon{}
 
 	SupportedKinds[BlobKind] = true
 	SupportedKinds[BoolKind] = true
@@ -106,6 +112,9 @@ func init() {
 	SupportedKinds[TimestampKind] = true
 	SupportedKinds[DecimalKind] = true
 	SupportedKinds[JSONKind] = true
+	SupportedKinds[PointKind] = true
+	SupportedKinds[LinestringKind] = true
+	SupportedKinds[PolygonKind] = true
 }
 
 var KindToTypeSlice []Value
@@ -134,6 +143,9 @@ var KindToString = map[NomsKind]string{
 	TimestampKind:  "Timestamp",
 	DecimalKind:    "Decimal",
 	JSONKind:       "JSON",
+	PointKind:      "Point",
+	LinestringKind: "Linestring",
+	PolygonKind:    "Polygon",
 }
 
 // String returns the name of the kind.
