@@ -14,7 +14,20 @@
 
 package val
 
-import "github.com/dolthub/dolt/go/store/pool"
+import (
+	"time"
+
+	"github.com/dolthub/dolt/go/store/pool"
+)
+
+// OrdinalMapping is a mapping from one field ordering to another.
+// It's used to construct index tuples from another index's tuples.
+type OrdinalMapping []int
+
+func (om OrdinalMapping) MapOrdinal(to int) (from int) {
+	from = om[to]
+	return
+}
 
 type TupleBuilder struct {
 	Desc TupleDesc
@@ -29,14 +42,20 @@ func NewTupleBuilder(desc TupleDesc) *TupleBuilder {
 	return &TupleBuilder{Desc: desc}
 }
 
-// Tuple materializes a Tuple from the fields written to the TupleBuilder.
+// Build materializes a Tuple from the fields written to the TupleBuilder.
 func (tb *TupleBuilder) Build(pool pool.BuffPool) (tup Tuple) {
 	for i, typ := range tb.Desc.Types {
 		if !typ.Nullable && tb.fields[i] == nil {
 			panic("cannot write NULL to non-NULL field")
 		}
 	}
+	return tb.BuildPermissive(pool)
+}
 
+// BuildPermissive materializes a Tuple from the fields
+// written to the TupleBuilder without checking nullability.
+// todo(andy): restructure
+func (tb *TupleBuilder) BuildPermissive(pool pool.BuffPool) (tup Tuple) {
 	values := tb.fields[:tb.Desc.Count()]
 	tup = NewTuple(pool, values...)
 	tb.Recycle()
@@ -45,6 +64,9 @@ func (tb *TupleBuilder) Build(pool pool.BuffPool) (tup Tuple) {
 
 // Recycle resets the TupleBuilder so it can build a new Tuple.
 func (tb *TupleBuilder) Recycle() {
+	for i := 0; i < tb.Desc.Count(); i++ {
+		tb.fields[i] = nil
+	}
 	tb.pos = 0
 }
 
@@ -60,7 +82,7 @@ func (tb *TupleBuilder) PutBool(i int, v bool) {
 func (tb *TupleBuilder) PutInt8(i int, v int8) {
 	tb.Desc.expectEncoding(i, Int8Enc)
 	tb.fields[i] = tb.buf[tb.pos : tb.pos+int8Size]
-	WriteInt8(tb.fields[i], v)
+	writeInt8(tb.fields[i], v)
 	tb.pos += int8Size
 }
 
@@ -68,7 +90,7 @@ func (tb *TupleBuilder) PutInt8(i int, v int8) {
 func (tb *TupleBuilder) PutUint8(i int, v uint8) {
 	tb.Desc.expectEncoding(i, Uint8Enc)
 	tb.fields[i] = tb.buf[tb.pos : tb.pos+uint8Size]
-	WriteUint8(tb.fields[i], v)
+	writeUint8(tb.fields[i], v)
 	tb.pos += uint8Size
 }
 
@@ -76,7 +98,7 @@ func (tb *TupleBuilder) PutUint8(i int, v uint8) {
 func (tb *TupleBuilder) PutInt16(i int, v int16) {
 	tb.Desc.expectEncoding(i, Int16Enc)
 	tb.fields[i] = tb.buf[tb.pos : tb.pos+int16Size]
-	WriteInt16(tb.fields[i], v)
+	writeInt16(tb.fields[i], v)
 	tb.pos += int16Size
 }
 
@@ -84,7 +106,7 @@ func (tb *TupleBuilder) PutInt16(i int, v int16) {
 func (tb *TupleBuilder) PutUint16(i int, v uint16) {
 	tb.Desc.expectEncoding(i, Uint16Enc)
 	tb.fields[i] = tb.buf[tb.pos : tb.pos+uint16Size]
-	WriteUint16(tb.fields[i], v)
+	writeUint16(tb.fields[i], v)
 	tb.pos += uint16Size
 }
 
@@ -92,7 +114,7 @@ func (tb *TupleBuilder) PutUint16(i int, v uint16) {
 func (tb *TupleBuilder) PutInt32(i int, v int32) {
 	tb.Desc.expectEncoding(i, Int32Enc)
 	tb.fields[i] = tb.buf[tb.pos : tb.pos+int32Size]
-	WriteInt32(tb.fields[i], v)
+	writeInt32(tb.fields[i], v)
 	tb.pos += int32Size
 }
 
@@ -100,7 +122,7 @@ func (tb *TupleBuilder) PutInt32(i int, v int32) {
 func (tb *TupleBuilder) PutUint32(i int, v uint32) {
 	tb.Desc.expectEncoding(i, Uint32Enc)
 	tb.fields[i] = tb.buf[tb.pos : tb.pos+uint32Size]
-	WriteUint32(tb.fields[i], v)
+	writeUint32(tb.fields[i], v)
 	tb.pos += uint32Size
 }
 
@@ -108,7 +130,7 @@ func (tb *TupleBuilder) PutUint32(i int, v uint32) {
 func (tb *TupleBuilder) PutInt64(i int, v int64) {
 	tb.Desc.expectEncoding(i, Int64Enc)
 	tb.fields[i] = tb.buf[tb.pos : tb.pos+int64Size]
-	WriteInt64(tb.fields[i], v)
+	writeInt64(tb.fields[i], v)
 	tb.pos += int64Size
 }
 
@@ -116,7 +138,7 @@ func (tb *TupleBuilder) PutInt64(i int, v int64) {
 func (tb *TupleBuilder) PutUint64(i int, v uint64) {
 	tb.Desc.expectEncoding(i, Uint64Enc)
 	tb.fields[i] = tb.buf[tb.pos : tb.pos+uint64Size]
-	WriteUint64(tb.fields[i], v)
+	writeUint64(tb.fields[i], v)
 	tb.pos += uint64Size
 }
 
@@ -124,7 +146,7 @@ func (tb *TupleBuilder) PutUint64(i int, v uint64) {
 func (tb *TupleBuilder) PutFloat32(i int, v float32) {
 	tb.Desc.expectEncoding(i, Float32Enc)
 	tb.fields[i] = tb.buf[tb.pos : tb.pos+float32Size]
-	WriteFloat32(tb.fields[i], v)
+	writeFloat32(tb.fields[i], v)
 	tb.pos += float32Size
 }
 
@@ -132,16 +154,50 @@ func (tb *TupleBuilder) PutFloat32(i int, v float32) {
 func (tb *TupleBuilder) PutFloat64(i int, v float64) {
 	tb.Desc.expectEncoding(i, Float64Enc)
 	tb.fields[i] = tb.buf[tb.pos : tb.pos+float64Size]
-	WriteFloat64(tb.fields[i], v)
+	writeFloat64(tb.fields[i], v)
 	tb.pos += float64Size
 }
 
+func (tb *TupleBuilder) PutTimestamp(i int, v time.Time) {
+	tb.Desc.expectEncoding(i, DateEnc, DatetimeEnc, TimestampEnc)
+	tb.fields[i] = tb.buf[tb.pos : tb.pos+timestampSize]
+	writeTimestamp(tb.fields[i], v)
+	tb.pos += timestampSize
+}
+
+// PutString writes a string to the ith field of the Tuple being built.
+func (tb *TupleBuilder) PutSqlTime(i int, v string) {
+	tb.Desc.expectEncoding(i, TimeEnc)
+	sz := ByteSize(len(v))
+	tb.fields[i] = tb.buf[tb.pos : tb.pos+sz]
+	writeString(tb.fields[i], v)
+	tb.pos += sz
+}
+
+// PutYear writes an int16-encoded year to the ith field of the Tuple being built.
+func (tb *TupleBuilder) PutYear(i int, v int16) {
+	// todo(andy): yearSize, etc?
+	tb.Desc.expectEncoding(i, YearEnc)
+	tb.fields[i] = tb.buf[tb.pos : tb.pos+int16Size]
+	writeInt16(tb.fields[i], v)
+	tb.pos += int16Size
+}
+
+func (tb *TupleBuilder) PutDecimal(i int, v string) {
+	tb.Desc.expectEncoding(i, DecimalEnc)
+	// todo(andy): temporary implementation
+	sz := ByteSize(len(v))
+	tb.fields[i] = tb.buf[tb.pos : tb.pos+sz]
+	writeString(tb.fields[i], v)
+	tb.pos += sz
+}
+
 // PutString writes a string to the ith field of the Tuple being built.
 func (tb *TupleBuilder) PutString(i int, v string) {
 	tb.Desc.expectEncoding(i, StringEnc)
 	sz := ByteSize(len(v))
 	tb.fields[i] = tb.buf[tb.pos : tb.pos+sz]
-	writeString(tb.fields[i], v, tb.Desc.Types[i].Coll)
+	writeString(tb.fields[i], v)
 	tb.pos += sz
 }
 
@@ -150,88 +206,37 @@ func (tb *TupleBuilder) PutBytes(i int, v []byte) {
 	tb.Desc.expectEncoding(i, BytesEnc)
 	sz := ByteSize(len(v))
 	tb.fields[i] = tb.buf[tb.pos : tb.pos+sz]
-	writeBytes(tb.fields[i], v, tb.Desc.Types[i].Coll)
+	writeBytes(tb.fields[i], v)
 	tb.pos += sz
 }
 
-// PutField writes an interface{} to the ith field of the Tuple being built.
-func (tb *TupleBuilder) PutField(i int, v interface{}) {
-	switch tb.Desc.Types[i].Enc {
-	case Int8Enc:
-		tb.PutInt8(i, int8(convInt(v)))
-	case Uint8Enc:
-		tb.PutUint8(i, uint8(convUint(v)))
-	case Int16Enc:
-		tb.PutInt16(i, int16(convInt(v)))
-	case Uint16Enc:
-		tb.PutUint16(i, uint16(convUint(v)))
-	case Int24Enc:
-		panic("24 bit")
-	case Uint24Enc:
-		panic("24 bit")
-	case Int32Enc:
-		tb.PutInt32(i, int32(convInt(v)))
-	case Uint32Enc:
-		tb.PutUint32(i, uint32(convUint(v)))
-	case Int64Enc:
-		tb.PutInt64(i, int64(convInt(v)))
-	case Uint64Enc:
-		tb.PutUint64(i, uint64(convUint(v)))
-	case Float32Enc:
-		tb.PutFloat32(i, v.(float32))
-	case Float64Enc:
-		tb.PutFloat64(i, v.(float64))
-	case StringEnc:
-		tb.PutString(i, v.(string))
-	case BytesEnc:
-		tb.PutBytes(i, v.([]byte))
-	default:
-		panic("unknown encoding")
-	}
+// PutJSON writes a []byte to the ith field of the Tuple being built.
+func (tb *TupleBuilder) PutJSON(i int, v []byte) {
+	tb.Desc.expectEncoding(i, JSONEnc)
+	sz := ByteSize(len(v))
+	tb.fields[i] = tb.buf[tb.pos : tb.pos+sz]
+	writeBytes(tb.fields[i], v)
+	tb.pos += sz
 }
 
-func convInt(v interface{}) int {
-	switch i := v.(type) {
-	case int8:
-		return int(i)
-	case uint8:
-		return int(i)
-	case int16:
-		return int(i)
-	case uint16:
-		return int(i)
-	case int32:
-		return int(i)
-	case uint32:
-		return int(i)
-	case int64:
-		return int(i)
-	case uint64:
-		return int(i)
-	default:
-		panic("impossible conversion")
-	}
+// PutGeometry writes a []byte to the ith field of the Tuple being built.
+func (tb *TupleBuilder) PutGeometry(i int, v []byte) {
+	tb.Desc.expectEncoding(i, GeometryEnc)
+	sz := ByteSize(len(v))
+	tb.fields[i] = tb.buf[tb.pos : tb.pos+sz]
+	writeBytes(tb.fields[i], v)
+	tb.pos += sz
 }
 
-func convUint(v interface{}) uint {
-	switch i := v.(type) {
-	case int8:
-		return uint(i)
-	case uint8:
-		return uint(i)
-	case int16:
-		return uint(i)
-	case uint16:
-		return uint(i)
-	case int32:
-		return uint(i)
-	case uint32:
-		return uint(i)
-	case int64:
-		return uint(i)
-	case uint64:
-		return uint(i)
-	default:
-		panic("impossible conversion")
+// PutRaw writes a []byte to the ith field of the Tuple being built.
+func (tb *TupleBuilder) PutRaw(i int, buf []byte) {
+	if buf == nil {
+		// todo(andy): does it make senes to
+		//  allow/expect nulls here?
+		return
 	}
+	sz := ByteSize(len(buf))
+	tb.fields[i] = tb.buf[tb.pos : tb.pos+sz]
+	writeBytes(tb.fields[i], buf)
+	tb.pos += sz
 }
