@@ -18,22 +18,21 @@ import (
 	"fmt"
 	"strconv"
 	"strings"
+	"time"
 )
 
 type TupleDesc struct {
 	Types []Type
-	cmp   TupleCompare
-
-	// Under certain conditions, Tuple comparisons can be
-	// optimized by directly comparing Tuples as byte slices,
-	// rather than accessing and deserializing each field.
-	// See definition of rawCmp for more information.
-	raw rawCmp
+	cmp   TupleComparator
 }
 
-type TupleCompare func(left, right Tuple, desc TupleDesc) int
+type TupleComparator interface {
+	Compare(left, right Tuple, desc TupleDesc) int
+}
 
-func defaultCompare(left, right Tuple, desc TupleDesc) (cmp int) {
+type defaultCompare struct{}
+
+func (d defaultCompare) Compare(left, right Tuple, desc TupleDesc) (cmp int) {
 	for i, typ := range desc.Types {
 		cmp = compare(typ, left.GetField(i), right.GetField(i))
 		if cmp != 0 {
@@ -43,14 +42,14 @@ func defaultCompare(left, right Tuple, desc TupleDesc) (cmp int) {
 	return
 }
 
-var _ TupleCompare = defaultCompare
+var _ TupleComparator = defaultCompare{}
 
 func NewTupleDescriptor(types ...Type) TupleDesc {
-	return NewTupleDescriptorWithComparator(defaultCompare, types...)
+	return NewTupleDescriptorWithComparator(defaultCompare{}, types...)
 }
 
 // NewTupleDescriptor returns a TupleDesc from a slice of Types.
-func NewTupleDescriptorWithComparator(cmp TupleCompare, types ...Type) (td TupleDesc) {
+func NewTupleDescriptorWithComparator(cmp TupleComparator, types ...Type) (td TupleDesc) {
 	if len(types) > MaxTupleFields {
 		panic("tuple field maxIdx exceeds maximum")
 	}
@@ -63,18 +62,17 @@ func NewTupleDescriptorWithComparator(cmp TupleCompare, types ...Type) (td Tuple
 
 	td.Types = types
 	td.cmp = cmp
-	td.raw = maybeGetRawComparison(types...)
+
 	return
 }
 
+func TupleDescriptorPrefix(td TupleDesc, count int) TupleDesc {
+	return NewTupleDescriptorWithComparator(td.cmp, td.Types[:count]...)
+}
+
 // Compare returns the Comaparison of |left| and |right|.
 func (td TupleDesc) Compare(left, right Tuple) (cmp int) {
-	if td.raw != nil {
-		// todo(andy): this is broken for signed ints
-		return compareRaw(left, right, td.raw)
-	} else {
-		return td.cmp(left, right, td)
-	}
+	return td.cmp.Compare(left, right, td)
 }
 
 // Count returns the number of fields in the TupleDesc.
@@ -94,7 +92,7 @@ func (td TupleDesc) GetBool(i int, tup Tuple) (v bool, ok bool) {
 	td.expectEncoding(i, Int8Enc)
 	b := tup.GetField(i)
 	if b != nil {
-		v, ok = ReadBool(b), true
+		v, ok = readBool(b), true
 	}
 	return
 }
@@ -105,7 +103,7 @@ func (td TupleDesc) GetInt8(i int, tup Tuple) (v int8, ok bool) {
 	td.expectEncoding(i, Int8Enc)
 	b := tup.GetField(i)
 	if b != nil {
-		v, ok = ReadInt8(b), true
+		v, ok = readInt8(b), true
 	}
 	return
 }
@@ -116,7 +114,7 @@ func (td TupleDesc) GetUint8(i int, tup Tuple) (v uint8, ok bool) {
 	td.expectEncoding(i, Uint8Enc)
 	b := tup.GetField(i)
 	if b != nil {
-		v, ok = ReadUint8(b), true
+		v, ok = readUint8(b), true
 	}
 	return
 }
@@ -127,7 +125,7 @@ func (td TupleDesc) GetInt16(i int, tup Tuple) (v int16, ok bool) {
 	td.expectEncoding(i, Int16Enc)
 	b := tup.GetField(i)
 	if b != nil {
-		v, ok = ReadInt16(b), true
+		v, ok = readInt16(b), true
 	}
 	return
 }
@@ -138,7 +136,7 @@ func (td TupleDesc) GetUint16(i int, tup Tuple) (v uint16, ok bool) {
 	td.expectEncoding(i, Uint16Enc)
 	b := tup.GetField(i)
 	if b != nil {
-		v, ok = ReadUint16(b), true
+		v, ok = readUint16(b), true
 	}
 	return
 }
@@ -149,7 +147,7 @@ func (td TupleDesc) GetInt32(i int, tup Tuple) (v int32, ok bool) {
 	td.expectEncoding(i, Int32Enc)
 	b := tup.GetField(i)
 	if b != nil {
-		v, ok = ReadInt32(b), true
+		v, ok = readInt32(b), true
 	}
 	return
 }
@@ -160,7 +158,7 @@ func (td TupleDesc) GetUint32(i int, tup Tuple) (v uint32, ok bool) {
 	td.expectEncoding(i, Uint32Enc)
 	b := tup.GetField(i)
 	if b != nil {
-		v, ok = ReadUint32(b), true
+		v, ok = readUint32(b), true
 	}
 	return
 }
@@ -171,7 +169,7 @@ func (td TupleDesc) GetInt64(i int, tup Tuple) (v int64, ok bool) {
 	td.expectEncoding(i, Int64Enc)
 	b := tup.GetField(i)
 	if b != nil {
-		v, ok = ReadInt64(b), true
+		v, ok = readInt64(b), true
 	}
 	return
 }
@@ -182,7 +180,7 @@ func (td TupleDesc) GetUint64(i int, tup Tuple) (v uint64, ok bool) {
 	td.expectEncoding(i, Uint64Enc)
 	b := tup.GetField(i)
 	if b != nil {
-		v, ok = ReadUint64(b), true
+		v, ok = readUint64(b), true
 	}
 	return
 }
@@ -193,7 +191,7 @@ func (td TupleDesc) GetFloat32(i int, tup Tuple) (v float32, ok bool) {
 	td.expectEncoding(i, Float32Enc)
 	b := tup.GetField(i)
 	if b != nil {
-		v, ok = ReadFloat32(b), true
+		v, ok = readFloat32(b), true
 	}
 	return
 }
@@ -204,7 +202,51 @@ func (td TupleDesc) GetFloat64(i int, tup Tuple) (v float64, ok bool) {
 	td.expectEncoding(i, Float64Enc)
 	b := tup.GetField(i)
 	if b != nil {
-		v, ok = ReadFloat64(b), true
+		v, ok = readFloat64(b), true
+	}
+	return
+}
+
+// GetDecimal reads a float64 from the ith field of the Tuple.
+// If the ith field is NULL, |ok| is set to false.
+func (td TupleDesc) GetDecimal(i int, tup Tuple) (v string, ok bool) {
+	td.expectEncoding(i, DecimalEnc)
+	b := tup.GetField(i)
+	if b != nil {
+		v, ok = readString(b), true
+	}
+	return
+}
+
+// GetTimestamp reads a time.Time from the ith field of the Tuple.
+// If the ith field is NULL, |ok| is set to false.
+func (td TupleDesc) GetTimestamp(i int, tup Tuple) (v time.Time, ok bool) {
+	td.expectEncoding(i, TimestampEnc, DateEnc, DatetimeEnc, YearEnc)
+	b := tup.GetField(i)
+	if b != nil {
+		v, ok = readTimestamp(b), true
+	}
+	return
+}
+
+// GetSqlTime reads a string encoded Time value from the ith field of the Tuple.
+// If the ith field is NULL, |ok| is set to false.
+func (td TupleDesc) GetSqlTime(i int, tup Tuple) (v string, ok bool) {
+	td.expectEncoding(i, TimeEnc)
+	b := tup.GetField(i)
+	if b != nil {
+		v, ok = readString(b), true
+	}
+	return
+}
+
+// GetInt16 reads an int16 from the ith field of the Tuple.
+// If the ith field is NULL, |ok| is set to false.
+func (td TupleDesc) GetYear(i int, tup Tuple) (v int16, ok bool) {
+	td.expectEncoding(i, YearEnc)
+	b := tup.GetField(i)
+	if b != nil {
+		v, ok = readInt16(b), true
 	}
 	return
 }
@@ -215,7 +257,7 @@ func (td TupleDesc) GetString(i int, tup Tuple) (v string, ok bool) {
 	td.expectEncoding(i, StringEnc)
 	b := tup.GetField(i)
 	if b != nil {
-		v = ReadString(b, td.Types[i].Coll)
+		v = readString(b)
 		ok = true
 	}
 	return
@@ -227,51 +269,34 @@ func (td TupleDesc) GetBytes(i int, tup Tuple) (v []byte, ok bool) {
 	td.expectEncoding(i, BytesEnc)
 	b := tup.GetField(i)
 	if b != nil {
-		v = readBytes(b, td.Types[i].Coll)
+		v = readBytes(b)
 		ok = true
 	}
 	return
 }
 
-// GetField reads the value from the ith field of the Tuple as an interface{}.
-func (td TupleDesc) GetField(i int, tup Tuple) (v interface{}) {
-	var ok bool
-	switch td.Types[i].Enc {
-	case Int8Enc:
-		v, ok = td.GetInt8(i, tup)
-	case Uint8Enc:
-		v, ok = td.GetUint8(i, tup)
-	case Int16Enc:
-		v, ok = td.GetInt16(i, tup)
-	case Uint16Enc:
-		v, ok = td.GetUint16(i, tup)
-	case Int24Enc:
-		panic("24 bit")
-	case Uint24Enc:
-		panic("24 bit")
-	case Int32Enc:
-		v, ok = td.GetInt32(i, tup)
-	case Uint32Enc:
-		v, ok = td.GetUint32(i, tup)
-	case Int64Enc:
-		v, ok = td.GetInt64(i, tup)
-	case Uint64Enc:
-		v, ok = td.GetUint64(i, tup)
-	case Float32Enc:
-		v, ok = td.GetFloat32(i, tup)
-	case Float64Enc:
-		v, ok = td.GetFloat64(i, tup)
-	case StringEnc:
-		v, ok = td.GetString(i, tup)
-	case BytesEnc:
-		v, ok = td.GetBytes(i, tup)
-	default:
-		panic("unknown encoding")
+// GetJSON reads a []byte from the ith field of the Tuple.
+// If the ith field is NULL, |ok| is set to false.
+func (td TupleDesc) GetJSON(i int, tup Tuple) (v []byte, ok bool) {
+	td.expectEncoding(i, JSONEnc)
+	b := tup.GetField(i)
+	if b != nil {
+		v = readBytes(b)
+		ok = true
 	}
-	if !ok {
-		return NULL
+	return
+}
+
+// GetBytes reads a []byte from the ith field of the Tuple.
+// If the ith field is NULL, |ok| is set to false.
+func (td TupleDesc) GetGeometry(i int, tup Tuple) (v []byte, ok bool) {
+	td.expectEncoding(i, GeometryEnc)
+	b := tup.GetField(i)
+	if b != nil {
+		v = readBytes(b)
+		ok = true
 	}
-	return v
+	return
 }
 
 func (td TupleDesc) expectEncoding(i int, encodings ...Encoding) {
@@ -285,8 +310,12 @@ func (td TupleDesc) expectEncoding(i int, encodings ...Encoding) {
 
 // Format prints a Tuple as a string.
 func (td TupleDesc) Format(tup Tuple) string {
+	if tup == nil || tup.Count() == 0 {
+		return "( )"
+	}
+
 	var sb strings.Builder
-	sb.WriteString("[ ")
+	sb.WriteString("( ")
 
 	seenOne := false
 	for i, typ := range td.Types {
@@ -300,6 +329,7 @@ func (td TupleDesc) Format(tup Tuple) string {
 			continue
 		}
 
+		// todo(andy): complete cases
 		switch typ.Enc {
 		case Int8Enc:
 			v, _ := td.GetInt8(i, tup)
@@ -313,10 +343,6 @@ func (td TupleDesc) Format(tup Tuple) string {
 		case Uint16Enc:
 			v, _ := td.GetUint16(i, tup)
 			sb.WriteString(strconv.Itoa(int(v)))
-		case Int24Enc:
-			panic("24 bit")
-		case Uint24Enc:
-			panic("24 bit")
 		case Int32Enc:
 			v, _ := td.GetInt32(i, tup)
 			sb.WriteString(strconv.Itoa(int(v)))
@@ -342,9 +368,9 @@ func (td TupleDesc) Format(tup Tuple) string {
 			v, _ := td.GetBytes(i, tup)
 			sb.Write(v)
 		default:
-			panic("unknown encoding")
+			sb.Write(tup.GetField(i))
 		}
 	}
-	sb.WriteString(" ]")
+	sb.WriteString(" )")
 	return sb.String()
 }
